
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python Fintech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2)\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92)\x00\x00\x00\x00\x00\x00\x1a4\x9a\xbf\x1c\t\\\xc4\xa4\x1e/WIX\xbd\xda\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xc8\x84Ey\xe53e\xf3\x02wk\xd8\xeb\xab\xd0\x95j\xad\x82\x80Z`\x8f\x1a\x9f\xa6&\xe0\xdf\x80V;\xf7f\xf5\xe1\x0c,\xe3C\xd7\xbat5\xca;U'
        b'\xd8\xef]5\x0f\x92QY\x1a\xd9\xd0-I\xeaL\xec &#\xaau\xf1\xa2\x9dP\xc3\xc1^\xe6<:2\xe4\x04\xa5+\xf8\x07~\xecw\xbdC\xc3\xaf\x18\x0f\xa4\xd3\xe5\xf2\\\xcd)\xe2U\xdf7\xe5\x97\r\x8c\xfd{'
        b'\x90l\xfa\x08Q\xfc\x8aH\xb8\x05X\x07\x06\xb4\xd4\x106A\x12\x19^+\xe9\x10c\x04\x16"O\x90jK\xb7*\xea\xca\xe0JB\x1d\xa4W\xc3*\x1ct\xc4\x8a1v\x8d\xbe3|u\xfdw\x89-^\x88\xab\xb1['
        b"PF\x0b\x16\xe5\x97\xd8\x90.s\x00\x16\xdb\xc2\x94\x0fK\n\nf\x1d\x84\x84d}\xeb'\xb5\xdf\xb1\xce9\\\x88\x82u\x9a\xaf\xee`[\x83\xf8\x957h\x04\x8a\x1f\x01\xab\xf4\xd3\x0f\xc9_\xcf\x0fe\xaaQ\xe3\xad\x16"
        b':\xd7\xe6R\xe6\xac\x84p\x1b9\xe5\xcf\xf5\xe8\xf61\xccCrYDz\x17\xc4\x7f\x05\xf7\x9b\x91\xf2\xf2\xe5\xe7\x9e\xbc6x)I\x08\x8b\xeaD\xb5\xbbP6\xfd\x1d*\xf1\x07\x88@u\x9b\x19\xa1\xe4*\xb5p8\x1f'
        b"N\xe6\x9ar'\xc8u\xc1\x0eJ(\xa5)Ta\x8aQ\xa0\x96q\x16\x93\x9ej\xd7\x9d\xe2\xd6\x87{20\x94\xb1\x92\xdc\xf1H3\xe3\x7f>U4\xf1\x11\x015\xb6r\x8aG\xf0-\xe8k\x04\x1d[\x1c\x02\x9f\x982"
        b"1\xbf\tX\xd8\xec\xe1q\xa5\n\x9d\xb6'\xc9\xa8v\xaa.\nR \x8c\x04\x0fn\x17k\x84\xb5\xdf\xe1\x94\x05\xa9\x93-;1/\xbc\xbfL\x04\x8e)\xf8{\x0c\xea;&\x98\xae\xbd\x96~\xccGpW[\xc9\xa21"
        b"\xdbk\xbe\x98A\xfe\xbe\xe5x|\xe5\t\x12\xef'\xe3\xef\xea+q\xccR(:d\xf8\x9d4&\xa2\xa6\xf4\x19\x8c\xce)\xf8A\xba\xcc\xfcB\xb7\x9e\x11\xbfnkK\xb8\xf0\x1e\x1a\x10\xf6;\xe9y\x0b\xd7\xa7\r\xbc "
        b'\xa1\xd0\xe1\xaa\xc3\x98\x19\x0c~\xc19\x8a\x80\xd7@\xe5\xb6\x07\x13|\x8d\xd2\xd3\xaf]>\xd7A\xf6\x84\xbdz\xd1\x06Zn\xeeJ\xea\x15\xc6\x9ce\xb5\xdc\x1c\x99\xda\xda\xa6\xda\x19z\xdd\x04Y\xc9R\x8a;\xce*\xb1 '
        b'\xdb\x1f\xb4\x0b\xe65Cto\xe8\xda\xce\xc7x\xc3\x99g\xa3l#\xfaRAzM":K\x86\x92\x9a\xefg\xab\t\xb9\n\xf02\x90-\xd7\xcb\xd1a`4@\x0c\xe9\x12\xdd\x02\xa6\xe3\x83\x89\x97#q\t\x18z\x89'
        b'\x80\x95\xaf,\xaf\x90#\xd8\xc4\xaf\xf2/;@\xa8O\x91\x8b\x06\x16\xaf\xfd\x19\x92$K[\x95\x83\xfb\xb5\x85\xae\xf8\x14\x93\xb1\x81\xeaH\xd8\x1f\x8f\x9f\x93\xbf\xa4\x82\xe3M.\xf2\x8f[\x0eH\xaf\x80\xae\x0f\rf\xf2\xa3'
        b'\xb4A|\x82\xd0b\xd4]\xa4)F\x9b\xddn\xd3s\xa0\x13\x9by7\xc1\x86\xba\xf3?\x8b\x1d\xa3a\x0fe\xec^\xb7\x1c\xb3\xb6\x15{-\x02\xfa[\x84\x17X\x01\x97k|\xd6\xb4\xf6\x94[\x1f\x90\xe5\x0c\xf8\xf7\x8a\xe8'
        b'En/\r-\xb7W\x0b\xc5_\x7f\x94\x9by\x016\x13[=\xd1\xbea\xeb\xf4_m\xa6o\xb6\xceq\xe5\xf5\xa8\xa0\xca\xbef\xa9\xb9l\xd5\xfd\x98\x1al\x94\x88c\x05\x18\xfbIW6\xbc\x92Da"e\xd64\xda'
        b'\xd1\x92\xc1\xcb\\\x86\x0c\x93\xb7W\xc8\xc1Dt\xb6L\x1b\xab\x9a~t\xeaM\x12\xac\xaf\x8aC\xfc\x1fY\x83~\x8c\xfe\x7f0\xff\x18\xc6\n\xd4\x0c@#5!\x8fN\x02j\xd9)\x08\xdf\xaf\xc6\x99\xces\xd8\x12C\xb0'
        b'V\xdd\x9cJ\x06{\x83%%\xc3\xbbZ@\x05\x969/\x90{ZoU\x138$0x\xf2^o\xf2P\x05\xcb3%a\x9f\xac\x14\xf3\x8c\x11\xdc\xd5\xd1\xf2h@\x15\xb4\xda\x14HW\xa9\x19\x87_\xc1\xf1Ou\xe6'
        b'=\x82*\xe3\x15\xcb\x17x\x87\xcei\xde\xcb\xc7\x80\xc2\xde{\xc8\xf8\x88\x92S3[\x1b\xf9\xfa\xa0\x03\xf4\x86\\\xda\x80\x8c\xf7\x88\x9b\x13\x16\x00cm\xc1`\xad;\xf5w\xff\x87\xd1*\x88\xc8\xde\xefV\xc6 gV\xad'
        b'\xb6#\xa9\xed\x19\x82M\xe8\xd2\xabik\x9a\x17\xbb\xe2n\xad\x9e\n\xfa\xb2\x0f\xb6\xc83z\xd9s\xebs\x0e\x19\xc6\xf8\\@8\xf3 {\xa3>@\x12\x99\xb0\xd5"\xbc\xc6C\x81Q8U\xe2,\x04\xf3\x83\xf7N\x05'
        b'\xf0\x81~W:\x04\x1ca"\x14\xdf\xb7\xe6M\x90\xadG\x1f\x84\xe7\xcf\x05\x02\xe7\xb1\xb9*Qt2v\xabG\x88X\xeb\x99\x08\xfe\x8f\xfcX1y\xf1\x18 <\x05"\x1fp \xde\xb8\x17s\xfa\x8a\x89\x8f\xbcR\x8e'
        b"\xe1\x1c\xbe\xf4}\xd4\x97g\xe0\x99g%Y\x92:5Kq'\x01\x10\x1f\xd1u+\x11\\\x18\xeeK\xc2`\xf4\x05\x94\xce\x85 y\x13\x9a\xbah\t\xe6\xd2\xbeA\x0c\x14M\x90\x1f\x80$\xb9X\x83\xdd\x1a\x87\x1a\x13V"
        b"TJ\xf8\xe5\xba:Wi\xce\xdf\xf1\x18\xdd\x9f\x17A&\xcd\xb6\xf7\xbaG\xee1\xb0\x88\xd2\xed\x9c\xe0p\xde\xb1'7\x15.&\x01\xd5\xe0(\x95\xadr\x03\x8d\x1b\xb3\xf9\x94h\xa7r|\xa94\xa6\xc9\xdfb\xb4\x00\xf3"
        b'\xd7ip\xa2\xfe\xa1x_\xf0P\xa30\x90\xdd@\xe4\x89?\x10\xa1\x89\x12@\xbd\xe7\xd5\xa4\xdf\x00$\xe1\x8f\xde\xe2\x0cS\x81\\\xb3\x19)\xf7\x90yN\x15\x16/\xf0\xc4%\x96a`B\xfb}\xd2dcN\xa4x\x9a'
        b'\xc8\xdemp"_\xb1\x9eE\r\xd06\xcd\x92L\xa0T\xa5\x91M\xfa\xf2\xac\x12\xedY\x03,A-\xfc\x03\x95\xc2\xe8\xf4\xe49n[\x95\x1cQ\x1d\x07\xe3\xb0\xa5\xf8_\xd3\x10=!%6\xf4\x0cSd\xdf\x9b3\xc3'
        b'\xd0\xd8\xab\xaa\xb3\xfd\xaaAi\xd5"\xa4\\]\x93\x9d\x96\xf5\xfd?\xb9\x17~\xa3(@\xaa\x06\xa6\xf9\xeb\x84|\'\xad\xa4\xac;\xd5\x7fMT%\xfd^\x81\x14\x86\x87\xf5\xe33\xf1Q3F\xbc\xdd~t>.VJ'
        b'\xed\x88\x03\x7f\xc2\x97C#\xc6\xa0\x8c"\xe6F\x8dw}\x93\x85\x89N\x1a|\'WZ>@ON\xa8*\xaa=\x98\xcf\x15\xb9\x96s\xbd#\xaeU\xa0D\x98\xdds\xf7\xdc\x97#\xdbQ\xd5\xc3\xc7S\xc6^\x91y\xf7'
        b'<\xb1\xbd\xd52[\x0c\xc0K\xb0:\x1d\x10\x7f^g\x8f\xac\xdc{\x8a\x9d\xb8\x90\x9f*\xfe\x84\xebr\x03\xd6\xb1\xca\xae\xe5(tY2\x98\t\xa6\xf4\x83\x1e\xc0\xadY\x92)\xbc\xa6\x0c\xc8a\xbe)\x82\xb9\xe4\x9f\xde\xb4'
        b'\x1fX{F\xf2\x84\xd8\x06\x8cx[\x8c\x9c\x88\xc7\xe6+8\x17y\xa9\xd6X\x1eg\xe6\x0e\xc2o\xd7\x86\xab\rC\xb74>\xb49\xceNrz6_|\x9d\x06\x05j\x83\xb6\x0ck\x1f\xd3\xa3\xe9\rO\x82\x8f\xa1\xec'
        b'O\xf9+|\xf0\x07\xa1\xc3\xd9\xd7\xfc\xd2h\x98\x9b>\xf4\xb7M\x96\x19\xe3*\xc2E\x96~\xc5A\x05\xc6\x8c\x9a~:f\x18(\xfd\x82UT\xf6f\x16r\xca\xf41\xcd\x1f&d\x83\xb2~r"\xd5y1\xc3\xa6\xf5'
        b'\x02j6\x92\x1d\x17\xcc\x06\xb8uV\x81\x95\x93\xee\x0c\xd6u<)I\xa7E)\xd7\x1a\xf4\x98\x95\xae\xa5\xc9\x81#\x16=HM\xc9\xd14\xc82\x14rE\xab\xc7D\x9c\x98eM P\xe1:\x0f\\MU\xbb\x11\x0e'
        b',\xdd#\x9c\xb9+\xbf\xd5&\xbe\xcb_\xffc\x03\xf2\xe8H\xdd\x9e\x0cn\x91\xf8%\x8a\xcfuT\xe1R\xa3\x11\x10J\x91\t/}B7g\xca\xf1<l"\x8aS)o\xc2\xaex\xed\x98\x08\xecVc\xc6+\x14]'
        b'D\xd0\xeb9>N}D.\xfe/\x049Ru\xea\xe5\xf5HI\xe8\xa9\x9b\xc3rh:M\x85R\x92\xe2\xc1\x80\xe0\xd8t;q.\xde\x12\x8fgG\x1c\xbf\x82\xd9q[U\x88sU>Z\x02H\x8b\x1d\x1c\xac\x90'
        b'J\xaa\x9ajD)S\x8eg\x87\x1e\xcaK\x9e\xa9\x88\xd6uD\x843\xfe0Z\xf6}\x91x\n;\xd2\xa1\x1cZ\xdf8\xb4v\x13\xea-g\xda\xcd\x9f\x1d\xb5\xbf\xb7\\\x02\x94\x1d\xb0=\xd9\xe8\xd0\xd4m\xf6\xd8-#'
        b'\x8a\xbd^\x19!G\x85\xcfdz\xda\xb9\x02*\x08"8KI\xef\x9b)\xe1\x8c\xa7\x04\xc1\x05\xd0g\x00{\x01\'k\xe4zcu\x97-\x99Q\xce\xb5\x19r\xbbT\xc1\x97\xc1+\xa2\xed\x13J\x99\x95\x04\xcaM\xa3.'
        b'\xd7\x03z\x8bvD\xda\xbaE\xeeB\x97M0\xa9!\x84]\xc3~\xe2M*\xb5f#\xa1\xc7N\xd7w.oX\xf0\xe4\xff\xe6GnN\xf4\xc9\xde>q\x0ed\xf3\xc1\x1b\x97y\xc8\xc7\xea\xfd\xe5w4.U\xb8\x03'
        b'\x7f\x01Yp\x9a\xde\x81\xb7\xbc\xa1(\xa9\\a\x885\xe6\xb0Zc\xffN7V\xc0-\xa4\x1b\x96\xee\x03\xf3\xbd\xddT\xaeE!\x00\x03\xb9P\xb6M\xfa=\x90\x88\xc0\xad\x8fg]\x18\xbe\xf9\xe8S\x15\xb4\xff\xa2\xbc\xc7'
        b'\x00\xd2\xb4\xc1\xf8/@\xbc\x04\x8a\x1c`\xe2\x8fu\x89c3\xcd\xf3\x90L"(?\xc7\x0ew\xac\xda00\xac\xd9\x9b\xb5/\r\xc6X\xdc\x8dE\x1d06\x8e\xb0\x00/\x848\x82\x8b\xb4?\n\xe4\x06Jy^\xae9'
        b'\x86m\x9d\x0f\xa8!\xf8\x1a\x81\xeeX\xf3\xcd\x1c~F{f\xc6\xfa\xf88u\'\xaf+\x99-g\xaf\xb3"8\x96\xa3D\xcb\xf1_\xa0\xf8\x03\xca\xeb_m\xb7U@\x1f*=Y\xec\xfbCKR\x93\xce\xf9\x86\xa2$'
        b'\x1d\xdbO\x87\xee\xe74{\x98#l5A{\xb7\xb8\x17\xed\xa1x\t\x06\x13\x1bK\xd1\xe2\xb1H\n\x8a\x8f\x1dg\x129,\xedw\x98\x99\x8d\x82K\xcf\x9a0\xefsM\x1du[s\x8b\x82\x97\xc5\x9d,\x1f6w\xab'
        b'\x15\xc1hm\x90\xc5 \xf9\x8fy2\xfc\x18.K\x8bH\xaa\xa5e7\x98\x95\xef\x038E\xa9]~\xe5\xe1\xd4\xf2\xef\xd7\xdem\xfc.\x06G\xa4\xc2T\xd7\xc2?\x8b+3\x01z\xa0t0\x0c4]O\x8fb\x11d'
        b"\xdfo\xae\x14\xc9\xdb\x0c!c\xe3\xact\xf7Mu\xc0\xea\xce\x04\xa5\xf8$\x11\xf0\x1e\x95,\x17\n.\x04\x05\xe3W\xc7\x01zA\x1b\x8e\xb0U:\x96\xa6\x1e\x00lwG\xeb{\x8b\xf0\x1bmW\xabun\xff'\xc7\x98"
        b'\x93\x10 \x98\x13;E\x03\x90\t\xfd\xb4\xb3nKW\xbf.\xba7`n\x95U\xe3\xb3\n\x97\x16*\xd0\xcf\x1eh0\x83\x1e\xf5\xbf\xf7\xc1~\xe9\xef\xbd\xea\rk\xf143\xe0x_\x9c\xa2J\x882\xe2\xc8\t\xb2\n'
        b'[f\xc4\x05\xd9f\xa8\x7f\x8bh\x8b\x86\xbax_\x05\xfc\xb7B\xfa\xbc\xf6mza\xcd\xaf>\xde\x9ck\xff\x11\xf6f\x00X5I\xaa\xf5W\xd9\x19o\xc2\xb8\xaf\t\xeb\x1bPg\xf7\xd8U-Q\x92\xab\x8f\xaf+\xea'
        b"\xf8\xf40\xd0\x7fq\xbd,\x01\xeb\xdf\xfeD\xc4\xe2\x13.\x9d\x11\xb0\xefn\xe4\x01\xb0\xfa\x13c\x86\x1b'\x89\xf8U\xff\xb5=\xa8\x96\xab\xfa\xd0v!\x0b\x13\x8b\xa3\x8a\xda\xfb\xf0\xd2\xb2Q\x9cw\xe2C\xdeD\xbf\x9e\xd3"
        b'\x8b\x82\xfd\xdc\xad[\xf4\xe4&\xa5"\x7f\xe1\xafY3\xbf\x899\xf8\xed!\xca\xd3\xca\xb5\x0b\x0c]R\xe0\x9c\x10d\xc6\x8e\x16\x1c\x03!{\x80\xd2\xa9I0U/\xcc\xdfqs\xe1Q\xdb\xb1_\xa55+\xd4<\x92\x81'
        b'\x8a.\x85\xae}6\xe2?\x8eY\x1b8l]+\xf8\xaeGQ0\xeb\xa6\x19?\xbb\xfb\n\xfe\x83\xcap\xdd\xdb\xdd\xe8\x8a\x02dk\x9c\xc8\xcd\xf2\xa1\x16\xefTu~\xa6\xddfy\x04_\xbe\xb1\xd8\xf9.\xca\x8e\xeb\xc6'
        b'\xd8\xc1\xdc\xe0?D\x14}{\xfd\xc0mr\x8a>\x17\xf42\xb4BP\x04\x8e90W1\\\xe9Z\x8cR\xb2\x8cox\x97\x8b\x8d\x18\xf7X\xb4\x92\x08/ML\xbc"\xa5R\xc3qd\x11\xb8"_+%[\xa24'
        b'K4F\xd0g\xf8Hu\xe0\xe2N|\xe0\xe5\xdd\xe7\xd2\x9cf\x03\xb2\x90\xff)\xa8\x84z\xbc+bq\xdbG\xff\x89\xac\x88\x94W\\\xb1\xb7\xcd@l\x18\xe5\xa70\x1c\n\xddq\xfb\xa1\xc7\x92Q#\x1c\xacg\xdf\xce'
        b'\xf3^\xfa\xc5\xb8B?\xf7\xdba\xb5\x94v\xc9\x82\xcf\x02\xf2\x15\x9c$\xf7U\xce\x12\xd3B_|\x11\x8b>\xa8\xc7\x05/\x0e(\x0e\xf6\x98\xb2\xed/\xe4\xe8p\xa68\x9b\xbc+1\xa0zn9\xf4\x99H\xcd\xb5;\x00'
        b'\x93\xfb\xa5\x9fn\xbd\xe6>\x03\x84\xaflJ\x7fC\xaeBz\xd4\xe5\x10\xab\x14L\xb8:\x96\x08A\xa6(\xd3\xc0\xbb\xe6\xb5\xb4\xc3\x13\x9b\xf2\xa4\x8f\x93\x83\xa1W\x01\xad\xa7\x8f\x04\x98sUTW>s\x00-6\xba\xd7'
        b"\x8b\xf5\xad8'\xf4\xc0\x05!\xb0z6Ojg\xd0t\x9e\x03C\xc5\xf3\xf2K@4\x1e\xa4E\x0b\xd1(\x97\xa1\xd6\xed\xc1}\xae\t\x91\xbbh\xd8\x9e\x8d]a\x01brG\x8c~rs\xe6\x869\xda\xc2C#h"
        b'A\xec\x96o\xdc\x173\x7fGV\xc2v\xb1\xe7\xf5\x17\xb3\x19Ce\x8e\xa9[\xeb\xd3r\xbazJ\xd0YR9\xa0\x80\xccD\xd2ra\xc5\xf8\x97\x917\xf7\xc6\xd6\x1fL\xaa\x96\x9f\x0b\xecq\xae\xf7L\x0f9\x12\xd1\xe2'
        b'iM&C\xea\xb5\x8a\x12,\xb2?\xdf\x89{_5C\xb8\xed\x13I\x036\xbe\x9b\xcd\x9d\xf2\x19\x1a\x88#\xf31P\xc1\xa8\xfe\x08\xeembm\xa7S\xeb\xa1}\xc8\xa5\xa2J\xccB\xba\xa4\xab*Q&\xac\xf4\xcf\x8e'
        b'\xe2\x19\x8e\xf0\x17j\xb5\xa2\x01IJ94\xb8\xf8\x1f.\xd3\x86\x1c\xd8\xcd\xb5W\xcf\x1fm\xbaOU\\r\x81\xe2\xb7\x9a\xe7\x92\xf1\xa5\xe2\xf4\x18\xc8w\xc8\xb6\xb1\x9e[\x93\x97\xea\xe1\xfc\x84\x9d\xa3G\x10\xc0\xa9}\x8a'
        b'8\xd2l^\x0fa5\xbf\xda\xfa\x0b\xb5\xa9\xa9%C\r\xc77\xae\x8e_\xd3\x16|Z\xac\xcaDAc\x0c\xe2\xbe\xfdyW\xb0\x8a\xd5\xca\x011\x93\x19>\xa8\xc6y\x85\xcd\xcb\x0cbS[\xcc\xdc\xdd\xd9\x8cj\xccl'
        b'\xe5\x03\x8a8\xb6\x8e\xb7\xd2\xd2\x84`"\xab\xdbkT\xb9\xd0\xc9\x9dL`|\xb4\xde\\\xb8\xfc\xc1K\xe3c{\x1d\xe6\xdc\xd1\xb7\x06\x17\xef\xd5\xc9m\x1b5\xba\xcd\x95\x18g4fM\x07#lmnv\xe7\x92\x1b|'
        b'\xd1T\xa4\x9fY\xe2\x07\xd96\xe3\x9b\xb1\xf6$\x90\xa0\xc7cm\x92\xae\xc4\x1b?J\x84*[g2\xfd*\x92\xbc\xcfF\x98\x92\xdf\xec\xc2\xe1\x0b\xf9\xa0\xca\xbc\xae\xcfZ\x1d\x9c\xd9}\x88\xe8\x94\xfag*\xcd\xb6\xf4\x04'
        b'\x1f\xb5!M7\xb8\xef\x8f\xce\xe4\n)bZ\xb6\x01\xca\x8f"Fy,\xff\xe6>z/s\xbc\x88M\xa0)\x8d\x1b:\x06\xaf\xa25\xdc\x9a\x9b\xbcZ9l\x9c`H\x1e-\xe2\xa5\xd5\xe6\xcb\x08\xa3\xdb\xd83m\xdd'
        b'^\xe2X@\xe3\x9951eM|\x15\xf6\xbc\x0c\x17\x90\x05q\xaa\x92\xe3\x1dF\xde\x8a%\xf9\xb5\x9a<\x84\x08\x13C\x9aH9\x16\x00`\x9e\xb2\xf0\xc5h-\x1c\x91\xbd\xfaP@H=*V\xa9\x9e$3v5b'
        b'z\xef6\x9f\x03\x0eWw\xeb\x92Sj^gV;\r\x85(!V\xb8m\xdb\xb7\x11\x8aR"\xcdC\x83\x19\xe0\x88+\xcd\x92\xa9b\x16\xb0>}\xc6T\xd8\x9b8TH\xfe;\xe3q\xf9QT\xccw\xaf\x9b\xf3|'
        b"\xeb\xf7\x1f\x84\x9a\xf9\x1aj\xf0\xf9k\xf8\xd9@Q6\xf3mF\x04SXL\xbc\x9fS\xfd\xb8r\x9e\xbb\\\xbd>_\xfb\xc0o\x98\xd0\x8c{\x85\x96#\x8d\xa2_'\xbc&\xfd.\xb0\xdc\xda\xc5#\x85{y\xd9\xdd>"
        b'4\xa3k\xc0\xd6\xf9J\xbe(\x86\xc8\xb1\xec\xdb\x1dm\xdd\xe6/)\x93\xc4\xf6\xb7\x9e^`\xe9\x87\xae\xc3]\x8a\x94o\x9a\xc4\xdc\x800~\xc5\xf1\xaa\xce\x14k\xee\xbbA\xcf\xe9\x04J\xbb1\x10\xd7\xdd\xa1K\xf2\xf0\xf2'
        b"b\xa3p\x11\xc7\xbc\x01h\xbd\xfb\xa4b\xa7_\x18\x8b\xc21\xcd=go'<\xda\x02\xa2Rft@\xec\xb5\x13\xc1\xd6\x9fuNoP6W\x86\x07\xb6\x94v\xdb\x88@?\x95\x08\xbe\x9f\x8c\x87\x99\x0b\x18\x9b\n\xae"
        b'\x84\xce\xb8}\xaf\xa4\xa9,MwPQ\xaew\x95\xfc\x8d\xc8\x18I`\xacA\xd0E|\xe4\x17&\x15\x04&\x0bhb\x08l\xaf\x07\xf3n\xb4\x88\xf6\x15&\xec\x1d\xb24\rc\xf9\x11\xdf\x80\xe1\xf9\x81\xd8\x87\x8d\nb'
        b'\xf8q\xe5FE\x05u^\xe6\x03\xd8W"\xcb\xedz\xb0\xb6OQ\xa9\x16RZ\xc0\xa4u\x8b\x11\xca\xee\xd0\xbc\xfda1)~fs\x02\x08\xb4\x15\x01\x11\xa1k\x8du\xfd\x8bv\xd7=\x90\xa6!"j\x82h\x96\xb7'
        b'\xab@\xddo\xe8\xcf\x1c\x92\xd5]\xbb\xaf\xa3\xdd\xf4J,f\xbcJ\xa5C\xc8\xac\xe1B\x8dG\xbf4b\x86:\x10\xea#.\xe8:\x83o\xb1)l\x9c\xe3\x83\xc6\xc7\x95\x81pm\xd1\xac\xcd\xcf\xcez}\x87\xba\x8b\x8f'
        b'\x89\x08y\x1f\x18t\xeaQ\xe4]@\x00\xb6\xbe\xce\xeb\xddU\xa9\xdd7v\xfa\x15\x9c8\xa1\xfe\x06\xb2 |\xee\xfex\xce\xd1 %\r\xc8\xfa\xce*\xe8\xa3\xae\xf1h7\tH\xb2\x99\xb1L\x8d\xb8m\x0e\x07{\xb0\xcf'
        b"/\xd7\x89f\xdffY\x97\xe3\xc3d\xbeK\xbb\xd5\xc4\xd4\xafv\xd3<\xb6\xfb\xa4\xed \t,$\xf2Rg~M\x15;\xb7')\xbc\x1b\xdcX\xc1\xe0\x12\xd7\xc0\xab\xf2\xb8\x1avu\xc5\x85\xf8\xec\xffm\xb6\xfbS\xca"
        b'_\xc0\x01F\xffw\x14\x93\xb6xv\xdd\x04\xaf\xf1\x18~f\x16Q0\x95\x11&\xb2\xa2\xad\x1c\x84\xbc\xf6\x98n!k\x95\xee\xb5\x18\x86\xbb.\xa6\x94\x0f\xe8\xcb\xdb\xf6\xeaN\xa0\xd2,\xca\x8bn\xb8\xd2\xf4>\xe0\xdfJ'
        b'\xfd~\xa2<\x9e\x7f@q6\x9c\x18\xfc\x1dy\xd2\xa6:\x80\x18N1\xd6\x1f\xe1\xe7X\xc3\x02\xdc\x90\x9bwW\xe1O\xc8\xb2l\x90\xde{&~\x1c\xcb\xce1\x93\x1cGT\xb5\xab\x88\xa8\xa8\xe5\xa1\x8b\xa4b\x07q\xde'
        b'\x0c\xef\x0cK\xb4\xd0="\'\xc2\x11q\xac\x12\xb2\'1\xaa\x98\x007B\xe2\xe2%\x92E\x16WI^\xb0\xa6sO\x077\xa7\xeb\xd1\x88i\xadn!\xca\xbc\x83\xdbt\xedWx\xb0\xe2O\xe0\x9b\xaaO\xf9\xa4\xf0m'
        b"\xafF\x08'\xfc\x03\x18\x80\x8f)\xfd\x0b\x95>\xb2n\xa7\xf5{\xc5M2\x80t\xdfs\xb2\r\x02\x15\x86\x9d\xfc~\xa0\x1c\xf0\xdcL8\xf1\xedj\xdb\xd8\x91\x99\xa7\x9a\x04\xd8\xeb\xb4\xbbQl\x05>\xcd\xcd&g\x1e\xe8"
        b'8\xeb3\xf7\x82T\x14b\x9e\x1cF\x16\x86\xc3\x0f\x8ak4:\xc9\x05\x000+\xe8\x87\xc3\xbd\x04\xfbr\x14\x91\x8e\x98\x89\x97\xa0"`F\x1b\xf6\x91a,.\xc6@\x07\x1d\xa2\xf4|\x8c\xbf\x96\xad\x9aG1\xbdXJ'
        b'\x02\x90\x10\xa9\x1b\xd5nv\xff~\xa6\n\x97\x96\x9eX\xc4\x83\xc9B\xc8b\x146X3\x0b\x10\xc2Og\xa0?(v\xa0\x8c\x05\xcd\xb1\xb6\xe71?\xdf"N\xc2Lx\xf9\xcb\xf1\\\xba\tVJ\xab\x16\x08\xb1Q\xc4'
        b'\x8d\x91\xfe\xcb7\xd7r&\xd9\x1c\xe2\x97Y?\xed\xf2-\x9b%\xcbWh:\xf8\x00\\\xad\xa1\x89T\x9b\xc4\xb2H\x03z\x92\xfbr\xa7\x8c%\x97\xean\x07\xa8\xa7\xce[\x17\xd3\xb0\xeah]\xc0\xd3\x0f(\xa5\xf6\xd2\x7f'
        b'\xdaF\xe2\xafD\x0e\xf2\xda\xb9Z/\xbe.\xe0\xe4\xd4\xb4\xfa\xca?\xa8~(tW\x03\x133\xfa\x08\x88*$,\x02$J\xf8\xefD\x90\xec\xdbl\xfad(D\xb7\xc2\x16\xc2\xd6\x11`,\xe9S\xa9\x1cx\x93\xe0\xc3'
        b'J\xb7(\xcc\xfc\x93\xe1Q\xd6\xa7|\xacH\xe8@E\x1a\x00\n\x1dH\x05\xb8:b\x16]f\x0b6ECd\x94\x1b\xa8\x9e\xf3I@\xf54\xc5}z/0\xe3\xab\xe32\xe5\xa4\x07\xdf\xf5Oqu*\xed=\xbds'
        b'\xff\xaa\xc0u\x930\xc4\xb7\x98\x07R\xaaP\xcf\xc4\xc1\xa3\xdc\xa6#Q\xc4\x1d\xc01\x94\xef\xf7\x11\xba\xb7\x18\xb4\xd6\x93\xd3\xb7\xa0\x06\xb9\x8f\xba\x9e\xc2\xd1/\xb0\xa8\xeaH\x01-\x05\xc0\x0f\xb5aSj6\xbc\x91\xf0\xc7'
        b'\x94\xe4\x1a\xc1\x82\xefw\xd7\xb0\xb2\x80\xc4\xfa<\xd1\x18\x1f\x8b\xb1\x97\xca\xf8\x9a8\xf4\xd8\xaa BHp\x96\x19\x08\x9dtG\x11vGH\xdf8j\x1f,J\x19\xa8G9\xed|\xbe`\xbb\x02)\xfd\x0fCH\x93K'
        b'yD\x9c\xf7\xdc\xaf\x8b0\x10\x01Rib6\x98$\xcf\xe5\xa0@\x8e%\x0eu\xa6\xe0i\x16\xe2\xe7\xbd\xac\xe0"z\x8aN\xbaT\x7fxJ_t\xfc\x83yQ\x08\xf0\x9c\xe7O\xf9\x1d\xa9"\x1c\x97\x16\xdc\x9e:\xb0'
        b"*\x01F\x8e?\x8ccaC(d\xb7D6\x1d\xb6\xb3\x06\x93\xbe\xa1\xd6JraKe\x90P'L\xa8B\x80\xea3G\xcf\xaf\x7fo\x8b\xce6\x92R\xc5\xd5\x03\x00$\xb6X\xc0\x9eO\xc1v\xf1O\xdc,\xe0\xfb"
        b'\xf5V\xe9\xd8n+++\x9d|?\xf9D\xcb\xfa\xdc/\x97\xe2\t\xfd\xf08\x02\xeb\xfa\x02\xbd\xc5\x03\x01\xa5\x8eE?\xdd\xe5\x92\xdd\x06\xf0\xb6\x01\x9c\xc8\xc6\xb4\x9a\x0bv\x13\xa7\\\xabG\xecK\xee\xae\x04\xfc\x8f\x86h'
        b"E-x\x1b\xd6l\xdahw\x94\x8d$\xcd\xad\x9b\x9c\x1bY\x97\xca\x84^\xff\x13\x90\xfb'\xe7\xc8\xd4\x17\xb0wZcz\xaafM\x06dF\x9b\xb5\x9e\x83\x12\x87\x1cl\xcc\xc7\xda\x11V\xf6\xd0\xacw\xee\x04@m\x0e"
        b'@\xf44\x9a2{)\x1c\n\xad\xa7x5\x0f9t)\x07\x85\xc2\xb3\xf9\xeb\xbbz\xaf\x92T\xf3r\x91\xb8\xa8\xcc\x9e\\\x99r\xce\xe9\xdd\x9f3\xac\xa3 \xe8\xe7\x90\xdb\x7f\xdf\xf0\xfch\xe50\xde.JK\xa8B\x87'
        b'\xda\xfc\x88\xef\x85\xaa\x08\x81"O"\x0b\xb5g\xa3\x05\x13\x93\xa1v\xad%\xcd\xa8\xcf\xfa\xb5\xd9\xf7\xe6\x18\xee\xf5\x82c\x1bS\xf1^\xbe\x00\x92\xb4\x9f_\x1an\x0f\xd4\x8b\xa4\xddo\xcb\xa9\x04u~G\xec\xb7\xa7m\x1e'
        b'\xec\xafA\xd1\x88\x15\x9dp\xf4\x7f\xd1\xe1\xf3\xb0\xda7v\xdd-\xc85\x91\x03\x89\x1fT6y4\x90\x0f\x9b\xc8\xef\x14\xbb\r\xee\x04)\x03i>\xfe\xe5\x90[\x1a\xd5\x19\xaf\xa30\xb2[\xd6\xbd\xbc\x8c}^\xd6\x82w'
        b'\x06\x92\x8d\x17\xf4\x84\x94\xd6\x9c\x03\xd0\xe2\x02\xfc\x9eN\xa8*\xb4\xb6\xbdB\x0e\xee \x1b\x9c\x02ldsL$\xa7\x85\x0f\xb1g;bA_\xd6\xfa\n-\xdc2\xabj\xcd\xf8\xae\xef/\xee\xcd\xd9\x1b\xa2Rco\xf6'
        b'S\xf7\xe1`f\x1cwX\x9a\x00V\xa3~(\x1d~\x87\x8c\x93CA\x15\x1f\xd1q\xdb\x18 @\xa2I,]1.\xda\xc4\xb96C\x1d{\xa4{tp\x8a\x06!\xfe:\xd8+\xa0\tIjh\xf9\xfe\xbe\xa8\x05y'
        b'\xfa\xeb+\x01G\xa7\xc9\xc2n`C}\xa7\x84\x80j\xb6\x1f\x06\xd8\x08\x8d\x1b\xc7l\x18\xe9\xf6\xc2K\xb9\xe2UM\xf3\xbe\x84\x03*\xb8\x1d\xb4C\x8d\x86E\xe6\x98+#\xa0\x07\xd4\xecjOi\x0b\r\xb96\xcb8\xf9'
        b'\xa4\xdfE\xd9\x83\xf4j\xf5_\xda\x0b\x17\xdd\xad\x83\xc0\xe4\n/\xd9\xf59\xdcASiS\x96\xd3\xb01G\xdd\xf0\xe2W\x90\xaco\xe2\x16\x0e\x8c<\xdd\x92j\xca\xf3\xaa\xbf\xb5\xe3\xa9\xd1\x83\xd9\x93\x83\xa3\x91$\xd8\xa6'
        b"\x00\r}\tW\x00D\xf4(\xeb0/\x8a\xc41\xbe\xc6\x07-\xe6&X\xfa\xd6}\xdf\xf9\x84\x05\xf2Nv'\x95ge_U\xe0Q\x9fG\xe6\xbd\xfe\xce\xc9\xa8'\x1e\xbd\xe6\x14\xa5\x99\xfd\x873_\xa1mA\xe0\xde"
        b"\x86\xf5Y\xef[@\xb1\xbd\x14\xc2\xc8\x1ag|:\xb0gW\xb1\xa3\xbf\x86\xc7\xaez1\x8a\xfb\xee\xbc\xe2\xae\x00F\x9dW\xadB<\xc4`\xb4\x07\xe8*\x01\xe4\xa6\x12\x83\xefcc7\x0b\x0c\x08\xab\xf0'_hL<"
        b'\xac \x90\xc9j\xbb\x98]\xba\xbc\x849\xf8\xa7\xfc*\xd3\xfc\xc1x;)\xd6\n\x06\x9a\xc2\x92\x0esd$;\xe5S\roG\x83H\xe7\xfb\xc4\xc1[n\xb6aHQ\xafTg\x811fW\xc7\xc2L\x1a\xf5\x9c\xbc'
        b'x58\xad\xab\x92V_\x97\xbfu\x948\xb3\xe59-C/7\xc30\x7f\xfeo\xfd_\xd6\xcb\x8d\xb5?\xddx\xf9\x84w\xda\xe8\x85\xaegS\xd7\xfe\xa2V\x14\xb6\x87\x11\xc83Om0\x7f\x13\x07\xad\xf3\x8cc\x18'
        b"\xbds\x9e?N\xf9x\xbe\xcaf\x17\xf8\xbb\xdc\xb1\x86\xf5n\xb3'\x9d\xdb%^\xde\xa7\x8eO\x8e\xae\x06s\x04J_\xeeJ\x0e\x1di\xd4\x8a2\x15(\x84\xf5\xef\xa9\x05/\x8f\xb2Mn\xafG\xb3\x0eZ\xf2\x03\x13\xa9"
        b"^\xec \x944:\xff\xb8\x00\xcc\xcb\xaa\xdf\x18\x8a \xc0\x02\xb1L+\xa3\xc3'+\xee\xf9\x11\xfb\xa8\xa9\x18\xe4HY:\\\xe3\xeb\xb2\xd5\x90<e\x95`P%u\x03\xfc?e\xec~mI7\xa7\xef\xd1fe\x1e"
        b'<D\xa9<\xd1\xe1Q\xdbmH\x87\xf7V\x83\xb1\x13CT\x81\xcc\x9f\xc7;\xc3\xcfW\x96\x98A`Qtx\xbe[\'\x9am\x07zJ"\xa4\x10\xf8\xe7\x91\x88\xb9\x9f"\x14\x18m\xc7\xbf\xbc:R\x00\x04;\xf1\xd7'
        b"\xb89@\xc7\x92\xb8/@\xdc\xfe\xa8\xd4\x9d\xc2\x0f\xfbw\xeeK\xbez\x88\xf869\xaaOI\xaeh\xb6y\\M\x12\x0f\x94\xe4G>@\xf8\xf9\x8fw\x00G\x0b(\x1c#;\xae\x8bG\x80:e\x96H\xff'\x8a\x1b"
        b"\xd1i\t\xde\xdfB\xd8\xe1k0\x92\xa3\x03\xf1\x8dar\xa5\x9c\xb7\xc6\xfb\xed5Z'`PI\x1c\xb4\x11d\xde<~;\x84\xf7=\xc9&\x7f\xac\x11\xe1zvH\xe7Mw+\xbb\xe4\n\xae\x8eZ\x19\x82Z\xfb\x8a"
        b"\x9b\x01\x04h\xc0. \xc7\xa3\xff\xf5eD\xe57%\x19@\xa1S/\x1b\x13\xd1V\xc2cJ'\x95\x10\xddp\xf5\xdb\xdf\t\xed\xc1\x86M2\tp\x93\x17r~D@\x08\x1f:\xc6m\xed\xf6\x95VS\xcc\xec\xb5\xd5"
        b'\xc1j\xd1\xd1]\xb3\xb0\x9e\\\x8e\xdd.\x16CP|\x9e\xdf^\xc5\x8f\xf5\x14\xee|+7IdI\x0b2\xf5\xd1\x82\xdc\x87doD\xb2\xcf\xf3\xed\xd6T\x94\x00H;\xa4\xdb\x1e\xb5h\x9e\x89\xe6JT\x87\x88\x17\xa6'
        b"i\xf74\xb8\xba\xb6\xe52\xb1|,\xc9R,N\x13]=\x9b\xe8\xac\xbad\xf0'\xd6\xeb\xb4\xe7\xf4\xecuM\x9e\xcc\xad\x14\x0cx\xec\xaf\xe4\xb2\x82\x92#\x9c\xc3LY\x81\x9dE\xbf\xde\xc4\x81\xa4\xad]\xae\xa0\x9d\xce"
        b'\xa8{\xeb\xf4=B\xcc\x07\xa0A\x87v\\\x8a\xdf\x02\xb6\x84Sc!\x0e\x00\xcdG\x84\xf5T~\x9f!\x90\x8ei\x8e\xc0T\xaf\xcd\xe8\x08(\xfbX9M\xdc5\xc07\xf7 ?(\xf6\xacQ"\xc2\x1f\x8a\xa5\xdcW'
        b"R\x12fl\x85\xe7&\xfd\x08\xe7\xe1\xc9\xa68\x11\xf0\x80\xdc\x94N`\xc7\x16\xab\xb2\xdb{\xae\x87\x1b\x89~\xd1\x07O\x0f\xd5\xafJ8^\xdf\xdd\xa3\xb2\x88o'\xe3t\xe8\xe586\xb5,v\\.\x10\xe7(&\x84"
        b'\x9d\n\x9c\xbaJWX\x0cm39\xfa\xb3r\x92\x0c-hJqU\x0cu\x03@\x852bq\xf4\x92\xb4\xbe,1\x02k\xec<\xa6\x05\xd0\x85&\xa1\xbcK3rq^]=\'M\xe2@\x86`\xff"BO\x0c'
        b'\xb6\xaf\xc7E|\xf3U\xa3\x13hdU7\xe4]\xbd\xcc\xb8*q\x16\xb6\x1e\xd8Jw=zo|\x8a\xd8\x9eK\x88#\xba4Z\x0f&\xc9\xbc\x1b\x18\x1d\tj_\x82\x80\xe7I\t\x1bx\xda\x94,h"(\xbb^'
        b'\xc1\x93\x19\xaahxS\x19\xa9\xf2\xf4[\xe3\xa6o\xac\xbf\xa4\x8a\x91$\x1a}(\xd6\xd1\xee\x0f \x96hRg\x00\x8c\xe4\x8av\xb5\xd0\xa2\xe7\x96\xaah\x9c=5~\xc8\x85\x9c\x83K&`\xa1\n\xee\xa6\x1f\xc0\xc6\xc6'
        b'\xd9_\xa2\x11`~k\xe3@\xfe\xa5*ga\xaf\xbat\xda\x88\x90-\xd4\xd2\x13n\xf2\xee\x81\xf7\xba\x92v\xd4\x00i~\x1d\x06\xd7\xa9v\x9d\xd9\xd9D\xd6YBs\xdc\xb3Z1 \xbf\x11\xe8D\xb60\x92\x88\xdd\xd9'
        b'\x1d\xdb\x13d\xf8x\xe2\xf6\x1c\xc8\x16,\x02J\x1a\xdb\x7f \x98\x03\xa7\xa1\xd8\xbf\xe3]\xa6\x1f$x_\x11\x13\xa5\x81\xf2\x84\x8f\x02ed\x14\xa2\x17\xa5\x1d\x84\x18\x80\xecm\x12\xf0\xe8\x14V\nY\x80\xcc\x8e\x0fr\x0c'
        b'\x05\x0c\xb1\xc3o`\xdf*b\xe4@\x10\xbc\xb3k+\xd8+Y9,\x9b\xc4\xe6g\xe1|\x91O\x13\xe4\xff\x9c\x1e\xc7\x84\x0c\xaa\x87g\xd2h\x82q\x92+\x02\x9c\xc5^\x90+\xab=\t\xb5\x9e\xff\xe0 \xe5Ozs'
        b"\xf6G\x01\xde\x15f\xb6\x00/j$>\xbd{K\xa7t\xb8\xb8\x11OL\x00\x8a'\xbb<>\x82E\x93\x1d\x15*\xff\x0e\xc0\x0b\xf1@:\xe6\xc0\x89t\xa5*f\xe1:\xba\xda#E\xd3\x80\x939\x1aN\xd3E8\xdb"
        b"\x1a\xe0\xe3('\x8c\x08#\x82\xda\xb5\xc8\x01\x8b\xb9`s\xc9\xbe\r\x13\xc4\x08k\xe4\x83\xe3\xee\xe3\xc1\x0f\xfc\x18\xb4\xfb\x00\x82\x02\xb7\x14+\x1cX\xba\xcd\xa8\r\x18\xa1\xda\xdd\x05\x91\xef\xf7\xde#?z\x11\xa7_n\x07"
        b'C\xc29d\x0f\x02\xb4`\xf2=u\xce\xd4F\x18\xde\xb3\xed-L#\x96\xb92\x0b\xcf\x8e|\xca\xc7,\x8cS\xb8P\x13\xc09J\x91\x9f\x92\x86\xc2HF\x81\x8d=\xf5\x1e\x92\xe3\xc5,^ V\xe9\x14\rz,G'
        b"\xac\x84s]\xd6\xa5\x9a\xd3YG!\x0f\x00nZ\x1e!\x18\xfd\x8a\xce8\x83k\xed\xea2\xbf\xeeW\x12'\xa0\xcd\x91\xd0\xa6\x90\xc6\xd5\x18\x9f\xac\x7fK\x00\xdd\xf5\xb9\xa7\x8fd\x16\x96>s;\x9e\xb3\xbe\t\x8b\x03\x85"
        b'd4\xe1T\x1dn\tO\xe0\xba\xb3\xc2u\x86yDUs\x84n\xaa\x16\x9f\xda:;K\xa0Ws\x81\xbb\x19\xdd\xeeW\x88\xa4\xb9\x90+:49\xb6\x92b\xa7\x1c\xd33a\xf1\x12Q\xdc\xa3\x86\xcb\x048\xa6\x0c\x10'
        b'\xd3\xee\xb6*\x01\xa6#\xfaQ\xb4\xa5\x8c5\xf9\xa1\xab\x17>\x87\xdb\xc1\xe0E\x8c\\pM\xdd\x88\x1d}\xaf\x06=p\xa0\x82\xd8\x9c\x16\x9d\xb2QR\x00\xaap%\xc9\xbe\xe5\x1fr\x18\xbb\x9a\x90\xa6\r\x9dHgr\xa8'
        b"'0\x15\xb0\xad\\yf\xaca\xdf@\x8e.\r\x83#\xa3<\xb7<\t\xbb\xd6\xa9\xf9>\xa5\x99\xb8\xb9\x89-\x83K|\xc4\\4V\xdf^\xf2(r\x9a#\xa8\x13 \xe8Dsd\xa3\xd14g\xb9\x8bY\x0fc "
        b"\xdc\xa8,\x87A3\xeaBQ\x12'P\x99(\x89:|\xed\xed\x8b\x03\x06\xc1\n\x0e\x9a\xa4\x12\x80\x87|\xe9\xc6o\xd8\xdf\x8f\x18&\xe0\xf6\xb5,\xd7J\xfe\xb3\x81_\xd5\x82*\xf3\x88\x1f=fC\xa7\x03\xe2\xdc,\xb7"
        b"\xc5\xa5\x89\xb3\xfe!\xd6\xf4\xa5\xb3\xbbC)'r\xc8/\xad\x96*\x07e\xa7\x84H~\xdb\xae\xf97\x97\x0ev\xb4\x12\x0e\xe3\xe1e\x18e\xcc\x11\xf9\x8e:p\xa1[P\x02\xc6\xe2\x19y\x92\x0c\x9c\xacJa\xd2:\xf2"
        b'.\xb0\x85\x19\xb0\x85-\xf1\x9f\xeb\xa9Je\xec\xffH:\x8b:\xe0\xc3v\xb8T\x10`#Z\x92\xf2\x1f\xca\xad\xd9\xb4\xc5\xaf$l\xdd\x98\xc2\xb4\xc0\xdf\x802\x19u%\x02\xf8\x9d\xdc\xb4*\x8b\xdc\x81x\xaf\xad\x97m'
        b'\xdc0(A|\xbf\xb1\xda\x88\x8eU\x05\x98\xa9<\xd0\xd4T5\xd9D\xdd\xfa\x859Jk\xf8\xe1\n\x8e\x04FPf\xaa\xc8\x168M\x7f\xeb\xf9\xe3b\xb2=vG\xb8\xc5\xc3\xa3\x85\xbfU1\xa1\xb5\xa6\x88\xb3^\xf8'
        b'\xd9\xfdR\x81\xdck\xbb\x80\xfcL\xdb\xd9\xa4\xe4e\xe9\xb4L\xd1\x9dp\x821=\xb9\xd2\xc7\xdc\xad\x16X\xd2To,\xc1\xa8\xe6\xef\xf1\xbd\x7f\xd5\x89\xe6\xc4\xe3Jq\xd79D\x0c\xefK\xb9\xdd\xb7\x85\xf9\x82\xd7\x83-'
        b'I\xca\xbf\x81\xfb\x8fN\xc4\x8e\x9a\x8fQ\xd9t\xba\x9b\xbbb\x0bX\x94\x8f?_\xa4\xf4\xcfp=\x0e\xf4F\x9b]CK\x1a\xa9\xe4c!\xb9`:w\xdb\xf9\xb1\t\xc7^\x12\\Kd(XnId\xcf\xd0\x86\x11'
        b'\x9dS\xaaf\xabX6Z\x01\x99\xad\xf0&\r\x01\xdb\xfc\xf4\xb8\xcc\xb6U\xb4$\xd7\xf4\x9b\x06\x81\x16\x97\xf8\x05\x81\x9fk\xad\x17!c\x7f\xdaU\xdej\x13\x800\xa8\xc3\x15d\xe3]\x08ho+\xa5\xaa\xc4\xb3z\x97'
        b'I\x9c\xac0\x8b\xde\xc5\x97\xf7\xe9\xa6k\xc5\xfc\x934\xa2\x13\xef8\t\xc4"\x86\\\xec0\x88y\xd8\xde!^ \xda\xabvr\xdf\x99*\xb3\xf9pX2\x90q)jvF\xc0\x90Kn\xb3\x12hC}E7\x9f'
        b'\xe2\xacwmxm\xb3T\xc6\x05\xb7\xed\x9f~j\xe1\xf3)\xb6+\x98\xdf\x02\xb2\xa1\xb7\xe7z\x8b\x88\xf5#\xda\xb2.j\xba]\xdb\xf4\x87\x82\xd8\x05\xcc\x03_s!\xd3U\x8aXp\x8b\xf9\xe5P/\xc0\xe2\x9b\xf4\x08'
        b"%\xf8\x1a\x9d\x01'\x8b\xac\xcfH\xd1\xb1\xa7\xab\xc3\xac\xb9\xfd\x103nH\xde\x95\x8c\xd9R6*\x03\xa1\x80{\xf7i\xea\x85~\xced\x1f\x01\xaa=\xfc\xcfn\x7fAD\x1eID__\xf6Y\xc9t\x14\xfa\xf3\xbe\xc9"
        b']\\Gb2\x0e\x0f4\x1c/\xc1q\xa9({\xe9*\x99H\x18\x15\xb6\xc2\xae\xbaa\xac\x1a\xd89G\x9e\x7fd9\xa2\x7f\x0eDw\x7f\xda|\xc1\xbd\x8e\r\xd9\xdf\\IV\x81\xa9\xce.5\xeah\r\xf3\x8al\x1d'
        b"\xfd\xf1[\x076\xf1R\xae,(\x8f\xb8\x8f\x0f\xb6\x04\x8d\xb7\x98\x89\xf8\xa0,\xf7\x8e\xc4\xaf[\xdd\x8c\xd0\xbau\xa3\x8d'\x1f\x03\xc0\xa7\x1b\x83\x91|q\x8f\xbb\xfd\xb1\xd3\xf0\xed\xf3\x83\x8b\xa7l\xd8\xd0\x9c\xe5\xef)\x9d"
        b'\x82=\x14np\xe6\xa3E\x1dE>\x8f\x89&1)6e\x95#\r\x11\xee*\x18\x15k\xa0^\xf3t\xe9\\io\xd4\x05\x0e\xb74\xd0\x96\xdf,N\xfcF\xd0\xf3\xbey\xc0R\xe6\xbc.\x88\x84\x95\xa82\xc9\xec\xd0'
        b'`Uyr>M\xe9Hx.\x13\x01\xf2\x0e\xc9\xa9._\xee\x1b\xafv>\xca\xc6\x1b&\xc6t\x84x\xb0\xb5o\xd9\x03\x98\xc7\xb5\xb9)t\xd7y\xda\x81\xc5\xb5\xd2\xc0\xdb\xab\xef(\xd4\x80-\xd5\xfd\x86\x06\x9fX\xcf'
        b"vY\xb2\xd2\xf1\x8d\xacYQ\xf3\xaf\xe76\xe7\xbc\xc0& \xc4\xecj<\x15_]5\x02\x92\x9c\xaa\xd0CA\xc3Y]'\xdce\xb8\xb0\x19\x98R \xa0w\x18\xe7\xb6&O\x91\x1a\x89\x95\xac\xdc\xa14\xa3\xd7R\xb5"
        b'\r\x13\xa2\xa05:\xd2Y"\xfd\x0b+\x83\xff\xd5^b4\x95\x9d\x90]\xb2B\xd8Z\xeb\xc0\x85\xb5\x8d\x1c\xd6nj E\x9eA{\x92\x97\xd0#Uhkq\x89\x89S\xb1*\x8b\xa1\x90\xbd\xde1q\xd1t/8'
        b'\xbdK\x19\x10\xc8\xd9\xce\xff\\\xc0\xc8\xea\x94\xda\xcd\x94/\x9c\xa1O\x87\xfe\xe8a\xca\x88*\xfd\x02x\x18 \x18x\x86)K\xb2\xe5_\xc7`\x0bP\xc4B\xba\xd3\x85\xad\xe8 b\x88\xeb\xdb\xebu\xe0\xa7\xc3\x12\x1d\xaf'
        b"\xc3\xd9\xefB\xe4\x0f\x90\x88\xf7\x97\x8fT5\xac\xe8\x86\x9c\xe2\\w'\x801\x9f\xaf\xf1%O\xa0\xb7\xbd\x91\x82\x95j\x1fM\xa2\x1fr\xab\xe0\xd1\t\xe8S\xf6\x92\xaf;oD+<\xeb\x12\x03\x81\x00\x89\xf8\xe0\xdf0"
        b'2\x1c\x89\x00\xf1-zh\xfbM\x18\xd9}nr\xea\xbb\xd0+\xb3v\xe3#\x89Tc\xcb\xc0\x1a, a\x9d\xe8\xfc\x87\xea@\xa7*\xad\x91R\xa4\xca\x9a g\x9e\xb8\xb2.\xcb\xaed\xb4\x1bc\xbd\\\xff\xf2\x817'
        b'\xaeo2>\x0e\xf4.\x03\x04[]fR\xcd\x85\x1d&.*\x83\x180\xc7l\xef\xab\xa0\x98jVJl\\O;\xb7\x97\x01\xea\xfe\xe6\xc9\xb7{\xffrAj\xb5\x9dj\xeb\xc2\x17\x04\x0eU\xb66\x92N\x06\xd0\xe0'
        b'\xc3Q\x1c\x00\xc1x\x1e}\x99\xbdL\xb3\\\xb1\x05T\x1c&%\xe4\xaf\x95\x06\xc9d\x13\x01\xa2\x9c5$\x0f\x1d \x9f\xa3X.e\xf7\x85\xa9lL\x85Z\xfaI@\xdd\xdd\xb4\x1a\xee>\'\x83\xad\x16"\xe7\xfc,\x01'
        b'U\xde\xa6\xfc\x1c+C\xff\xf8\xd5\x8e\x8b\xd2V\xaey\x01\xeaC\xdbq *\x98(t\xb2d\x8f>\xbeaJ\xeb5@\xc9E0K\x98\x03\xec\xd4\xcb\x8e\x10\xf6\x04\xd7\xe9\x97\xa0 \xeao\xeb\\\\6t\x08\x1fF'
        b'\x9b\xb2u\xe6\xfcX\xb2K\x0f\xdc\xee\xb7\xb2\xdaG\xcb \n\xe0\x91c{e\xe1\xfa\xd9\xd8T\xb9\x88\xbe\x93R\x03\xa6i\x07.O\xd8W\xd9\x01\xe7\xa0(TMw\xb9\xb0\xe1\xb2^\x00\xa5\x85\xd5\x94\xba\x8bN\xba\x11'
        b'\x0cSsj\x7f"\x93K3\x8fjFD\xd3\x81@\x04\x0fZh\x10*D\xf7X\xbcF\x90B\x9e\x97\xae\x9c\x04\xf6\x1d\xe1\x8aH\xed\xf7\xbb\xf9\xce9\xc7\x82\x19\x89\xb99\x95O,\x87\xbc\xd9\xdd\x9e\xcdo\xf4!\xbc'
        b'y\xc4\x17\xcd\xfb\xb4\x90\x0bO\xc7;o`,\x10X\x8d\x16|:\xf8 \xf8e\xcb\xb5TL\x8e\xf9\x99O\x7f\xcf\x10C,\x84\x07\xd0\x86\xac\xa0\xe9\xb4"\x82\xe3\xe4\xde}\xd8/\x042\xdd4M\x17\xc4\xd7\xb2\x16:'
        b"\x13\xbc\xd8+\x84r\xd4@\x8a3\xb2Y8\xfe\xf8n\xc7I\x9b\xc1p\x1c'a\x1d\xf1\xdfL&\x97{\x10\xe8\xe1Yu\xc6D@|\xab\xaaK\xfa\xecc\xaa\x1c\xa2\xeaw\x1c\x99\xa6\xc8\xdf?\xcb\xad\xe0\xdb\x8f\x8a\x8f"
        b'\xc7N8\x90\r\xe65S\xb8U\xf5\x92r\xe6\xa6\xe9\x97\x10\xfe>I\xc0\x96?\xabI\xf5\xac\xaa\xf3\xc7\xf7\x86T\x16sr\x83\t\xb7Z\xbc\xa7\x8c(\xac[sj\xcc\x94\xd6q\x97d\x9f\xe0\x93\x92_\xfa\xdd\xbc\xae'
        b'\xf8\x8e\xee\xab\x0f\x16\xf0Z\x89-\x06\xe37\x98\tO\x0f\x19\xdc\x8d\x14u\xc2\x84(u\r\xcdD\xbf-\x9dl\xfe\xe5\xfb0\x93\xd1BE\x18\xcas:\x8a4\xbfj\x7f=W\xbb\x9e\xfa\xf6\xa8\xa1\x8f\x82\x00\xffD\xaf'
        b'\x80d\xe5A\xa5x_\xf2\x1d\x82\xbe\xe4\xcd\xea\xa9\xb6\x19\r\xb0\xb8\x14d\x8b\xfd$=\xf4\xb1\xd2\xe0:\x150\xc72SCA\xb2\x01u\x8d\xf0\xd9\x19\x16\x88X\xc4/\x84J\t\xfare0\xc1\x9d\x8f\x16N\xa9F'
        b'\x1e\x92\xa0\xa3\x16~(\xb2\xad\xe5\xf12y\xf6!\x02\xe1\xb4Al\xf4\x13\xcc\x02\xc4\x97\x9c\x9efS\x19\xd3\x91T\x97\x8b\xfe\xdb\x86\xdaV(\x12\x8b\xd3\xcbz\xac=\xd0j\x8f\x7f\x0c\x7fg\xc7\xcc\x1ez\xc4\xb2\x80\xad'
        b'\x00\xee[\xe2S\x05\xb0\xe4\x02\x82{\xf9cG~\xfb1F\xf8W \x10\xccH.\xae\xdf\x02\xf7\xdd\x0c\x84/mdq;\xb4\xeas]\x06\xca)\x0b=\xe6\xafW\xc3~\x8a\x92G\xcdO\xa6\xb00\x9d`\xed+Q'
        b"\x0c\xc2\xf6\x8a\x99\xd4'\xc1\xed\xa7\x9c\x82)j\xd9H\xbf\xb3\xe4*\xd4\r\xe9\x97\xa5m\x82\xcfsj\xbd\x86\x1f6\xc6\x8c%\xe0\xc9\xfd=\x96\xbd\xc2)\xec\xf9\x0b\x18\x0e\x962\x89\x9f\xf1\xa7\xad\x10WA>x\xc7\xea"
        b',\xb35\xbc`\xc8\x8a\xfa\x1d\x04\xd5[d\x1fqr\xd1\xb6\x19eO\xfd\xabk\x03\x87\xa7>\xb4\n5\xe7\xbc\x83\xfd\xdaM\x9f/{4ywGb\xa48Z\xba|\x8e\x07`XP\xee\x99G\xc7\xea\xdd\xc3^Z'
        b'+\xad\xcf\xe0\xca\x1c\xd4\x06\xd8\x86u<[\x06#\xd5\xa9\xd0+\xccV7r\xec\x81)\xc9i\x81]\x04\x8cO\x14\x97\x890\xbe@]?\xdc\x87\xe6\x92\xd6\xc0\x01\xdf\xbc\x15\x9d\xec\xe4\xd8L\xa7\x02w/l\x9ar]'
        b' \x02\xc1\x9c\xcf\x8f\x19\t5\xc6Z\xc2\xb5\x81\xd3\xa5\xf6|\x9b\x97\x02\xf1\xdd\x0f6OnJ\xe6]\x19\xd8\x13d\xda)\xec\xcewL\x91\xf0\xb2E\xb4\xb1~j$9\x82\xf7po\xa6\x07\xa2=,o\xb9\x7fQe'
        b'\xd4\xe6\x9c\x9e&`\xa7E\x135\xf6)>Q\x99.\xf3\xc8\xec7\x00$\xc5\xe7H\xff-]-34\xdd\xe8t\x17\xa1,\xba\x03|\xf0g\xb5-\xcff\xf9 \xda\x16>\xf0\n_bu\xbd\x87\xd8\x0f8B\xa4\x19'
        b'\xb7B\xdaD\x81\xc3\x07\xd0\xca\x1e\xc0\t\xa2\xdeQ\x90h,\xea\xd5\x89\x08\x0b\xaf\x8ft\xde\x0c-\x07\x0b\x83N="\x11v\xa57/\xa2g\xe8\xfb\x9b\xe0^\x11\x86\x0e\x97]\x8b\xbdG\\g\xd7\xc5Q\xa4\x1a\x12k'
        b'\\\xd1\xc0\x1dx\x9b\xca\xaaL\x87P\xc4\x90\xae`\xc2L\xae\x90D\xa9?-\xbe\xfe<\x01\xad\x0ce\xc1Aj\xad)\xe0\xae"\x1e\xb5m<y\x17e\x88\xc2y\xa1\xaa \xa0F}\xbb$\x8b\x93^y\xa2\xd5\x16\x88'
        b'Tg\x9c9\xfa\x10\xa3\x00\xc2\xfe::s\x9c2\x86\xcba\xa5Y\x00\xdb\x9e\r\x0f0\xad(\xd0\xda\xa4\xbeV\xf2\xa3\x95\xb4\x03\x03\x86Ov^,\xc2K\x1c\x11\xcc\xd6\xa2\x93\xc7\xfc\x01\xe7\x9a\xf6vI\xe1.&f'
        b'+\x0ea\xcf\x87\xbc\xdf\x0e!\x94\xfd\x84)]\x95\xac\xc9\xe5\xfe\x11\xc1/\xb2\xdbT\x0b\x9e\xfe\x86*\xe8("\x96\xcb\x193\x07\x80\xb7\xfc\xbe\xeex\x1f\xaaWT\xbbR\x06\xc6\'\x8d\x9f\xfe\x8fN\x93\x16\x03\xa7[S'
        b"\x0c?\x05\x9dK\x05<\xebs5\xdd6\x97\xa5\xd5\xea\xe3\x0f9O\x81%\xffj\xd3\x93\x16@<\x91'\xc0\x88\n\xa8\xf2\x9c\x8a\xf7\x89\x02\xf2\xb7\\ei[\x9b\x9f\x97\xe3\x16$\x9c\xed\x06\x04\x80\x96x\xdd\xb3\xc8\xc6"
        b'\xc92(\xd2}p\xea\r_\xbc\x85\xc2\x11D\xbb\xeb\xf6\xe04,\xa2*g\xc1srf\x7fd\xa0}6\xaeD\x18\x1d|D\\\\E\x89m\xbb.t}\xb4\x01d\x81M\xc4Pi\x9f\x06G\x86\x89\xe8Q`\r'
        b'\xf8\x9c\xf4s%\xf4H\xa5}\xda*\r\x1cyf+n]\xdcQ\x0bf\xf2\xad\x90V\xbd\xb6(=\xe4\xc6Na:d\x88\xbd\xd0\x7f)n\x84\xebo\x141\x1a\xdb\xc8\x88DEu\xdc\xc4f\xb6\x96k\xe0\xc32\t'
        b'\xfe\xfc.\xf3\x9dY3\xda\xdd\x950\xe7u\xc6\xb7\x9c\x1d\x140\x95U\x16\x16\xf9\xa0\xee\xf6\xdcB}\x84\x03\xab\xd3\xd6\xf0\x04\xd5\xf0\x05[\xdb\xeb\xf3\xa4\x1c\xf8\xcb\xdb_\xa40\x91\xbe\xba\x06\xd2E2z\x9f\xc2\x9e\xcc'
        b'\x80\x9a\xe7b\x82=\xa0\xbeWY\xe6$x\xa0\xc0|\xf3|*\xfd"\xc6g\xdegxL\x1crX\xccQ\xb5\xe3t \xe0\xce\x93gK\x8aHv\x95D\xa4v\x08\xa4k*\x87\xc8\xe6\x06U\x1f\x80Ds\xc5\xec\xf8'
        b'L0e#\x8de\x06\xc2\x96\xe9\x97QbOl\x1f\xb8@"\xca\x13\xf0\xf3x\xc1\xde\xbb\xe85\xf7\xe8\x10]\xb8\x80\x9c\xb8\x0f\x9fE\xee|\x80"U\xc3N\xcf^\xa9\xb8\xd6\x01y2\x7f\xd9L}Gh\xa7\xa4\xb3'
        b"\xeb\xe4\xafz\xedC\x91\xf1HV\xbe\x84\xd6\xda]\xfe\x1d\xa2\xf8\x84-\xe3\x11\xf6V\x88v\x97\xcc\xed\xcb\xce\xd8\x18\xc4\xf7\x10u\xcfA\xa8'\xefHY\x7f\xfaz\xe4$\x160\xfad\x0c\x90h\xa7\x85\xca~\xdbK@"
        b'\x0b\x07`\xc6\xf8\x1d\x80\xaaD\x9ch\tD\xfd\x10E\x16\x96\xce\x89j\xdb\xd4\xb4mA\x8d4\xbe\xdb\xbd\xa3\x8dC\xe6\xec\xa3\xfe\xb4\x06\x85Zi\x8b\xad\xb5\xe6\x9a?l/\xbd\xa4D\x15;y\xda|\xfaf"\xb70'
        b'\x1c=\xcb\x9e9\xe2\x1fzi\xbf\x7f\xc9\xbf\xbf\xb3\xc5R\xc5\xb1Zc\x03\xea\xd87\x03\x03c\xf4\x1e\xc0}\x93N\x90\xf9\x07\x80;\xb3\xc9\xdd=\x13oj\xc5\xff\x82\xae\x97:\x95\x0f\x11~\xd8X\xa1\x85#\xbf\x8e\xcd'
        b"\x10\xe2\xe2\xf0\xc2\x10\xd3o\xe1\xfdI\xe3\xbd&\xfa\xd9\xac?\xb4\xc5\x802\xb05\xb7S3\xaf)Y\xf4%\x12\xd13\x0e}g'w\x17\x19\xf4\x8e\xfa\xc4\x05\x13\x03Pb#\xa0\xab\xa5\x19\x16f\xa0o\x9e\xe6\xa5\xc1"
        b'\x9f\x90I\x12\xb6\x18\x1f\xd5\xfe\x86\x7fN\xf10*\xa4\xb0Kn\x93Y\xb2^I]Y\xd6\x80*H\xc9U\xe6\x85/k\xda\xec\xd8&\xbcp~;\xf5\xc4}{e\x83\xfe\xc73,\x18U\xfe7<=\xda&(\t'
        b'\xf48q\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00'
        b'\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
