
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds2.\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xf2-\x00\x00\x00\x00\x00\x00\x06\x7f\xa4V;\x13<%\x19\x0f\x8f2\xa3\xa5+\x1b\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xb2\xb2KW\x8a\xf1J(W\xec\xf4\x9at\xd6<\xa1A\xc2\xd9\xf5A\x93\x06CPT\xd2U\xf6T\xae\x9d\x1c\x9e\xae\xffq\x00+\xd1L\x85\xd1\xfc\x13\xf9N'
        b'\xc2\xfa\n\xf4\x89\xfc\xa2\n.\x02\xaa\xe9G\xf1\xbcG\x0e /#\x7f\xae\x9bG\xcf\xa4e<R\xcau\x86\xa55l\xb0\xc2r\xd6\x91\xc7\xd3\x0b!X\xb2\xd4\x80\xfa\xd2\xe5\xc5\xd5\xd8\xd7\xef\xe2sE"\x92\xaa\xe4\xb8'
        b'V"\xbe\x87\xa9F~\xfc\x91\xbc\\\xe6\xfa\x93\xa7\x8e\x87\x98\xe8\xf2\xb2\xcfOA\xdd\x8f\x05:O\xfb\x8c\x87\xdf\x88\xd3!\xe2em\xb9\x7fu\x02G\xaa\x82\xb4{\xf5ms\x9a~\x92\xe3\xbfT\x10\xd1pBoq\x80'
        b'\xe7<\x01\xdd\x9c\xfb\xc1N\xf1\xa4Y\xc1.K\x13{1\xb3+\xba\x18\x9e0\xc5,\xb7-\x06\x84\x0f\xc6\xd9\xc3\xf2\xefR&\x104e\xf4=\xfeL%\xb4\xa1\xd2\x1b\x96\xd93Qw\xf8i\xe9_\xde\x9cV\xc3[T'
        b'K#\xf5\xf3W\xd25\xfcY\xffG\x82\xee\xf9\xd2\xbd4I\xba\xc4/\x0b1\xc1{\x82\xc8\x93"\xc5\xd0\xcd\xd2\x8b\xb8\x98:\xa7\x17\x9f\xe62W*\xf5\xf9\x8b\xe2\xa4\xd1q=u\xcd\x9b\xdfb\x07V~f&K\xf6'
        b'\x9d\x1a\xc8\xc0R\x94\x82 r\xfc\x8eErnW\xear\xbe\r:\xfd\xaa\x97\xadqk\x0cR\xa7\xe1\xeb\x13e\xe0\x05\x8cu\xf4\xb3\xe2\x8a\xf9?\xa5\x14\x15\xeee\x93\xa9U\xc3W\xb6\x9b\xac\xbb`\xae\xf9\xb9\x1aR\xd4'
        b'gu\x98\x06%\xb4\xc1\x8d\xadK\xdbn\xc9|[a!PX\xbcg\x11\xc3T\x19^\x02u\x95u\xe5\xadqL\xe7=!\xf3\xb0\x11\xfd\xdd\x89BZ\x97Q\xa3\xba\t1\t\xb5Dy\xa2\xbb\xdf\xf0\xd4\x96\x82p\xfb'
        b'\xe9\xde\xbeb\xe9Q\xb8"\x89\xd1\x86\xb5"\xce\x8be\xb5\x90\xa1\nB\x1at\xdc\\\xc6\xa8_\\\x15T\r5{d\x96\x16ZA\x93*\x83\xa6%\xefj\x81Z\xeeqI\x0e\xf4\xa45\x12!\x14\xd2B\r\xa7\xac\x00'
        b'^\xcb\x9b\xa4\x82R\xa9F\x0b\xf5\xdd.\xcb\xd81^\x9fg\xaf"\x8b\x07\x0c\\\xbd4\xfa"\x9f\x16\x93%\x08\x10^U\x8b\x11\x7fK\xbb=\xd0\xcb\x95\x01\xbeJ\xa5\x9c\x95x\t\xff\xe8+\x7f\xb9\x92<8\xa8\x03\xd5'
        b'`\xf6\xd7\xb3\xbb\xb8\xee\xa2\xa4i\x17\xae\r\xae\xa1\xf4\xa4/\x9a\x94\x89\xedq\xb5NB\xe8\xb3\xe0i\xcc\x04\xdd\x93\x87\x83\xc6\x98\x1bU\xb1\xa6<\xf2\xf7s\x92\xd5\xceV\xa53\xec<8\x04\xcd\xc8\x9dbG\xb7\n\x99'
        b'1\xddE\xdc\x90Uk\x08t\xed\xc5X^\xac a\x84\x89V\x12\xbdOC\xb6\xba\xb2M\xdfM\xa5\xbe\xcc\xab\xacq\xa4\xa5*\xe7q\x88{|\xd8E\x88\xbft\nd\x14u\x7f\xeb\xc1\xf8\xca!\xe8\xe9\xfc\xd3\xfcK'
        b'|\x18\x1fP&_{U!Z\xf4X\x1a\xec5\x9b\xcb|\x8a\xff\x00\r\xa9\x18\x1c\xc3d\x87}s\xa3\xf5\xb8g\xc3\\\x89\x08U\xd5\xe4\xa0\xbeg3W\xb2\x0b6\xd1\xcdI4\xc3$\x8f@\x19!\x89\x14\xf0\x1cv'
        b'\'\xb2\xdb\x82\x94fg\x95Bo\xa8|\x08\xee\xbd>\x83u|t5z\xb6\x02\xb2\xf6 \xd6\xd9\x7f\x1bM\xa7\xfa&*hv\xb7Ea"<\x10\xcf\xff\xads\xf1\xe6\x83\x18\x15\x92\xee\x9a\x0c\x8f\xd3\x00\x9e\x91\xe7D'
        b"*\xfb\x9d\xe7\x04\xd7\xdfb\xf1mc\x8f\xab\xcb]\x1cLz6\xcdA'\x89\xa5t\xb9\xc94\x08\xaaU\xdcwC\xb1\xfc\x9d\xe8v\xed18v\xca\x15\x8dd~\xe7`X\xdc(\xe5$=\xac\xb9\x8c\x85r\xff*\xb0"
        b'\xcb\xab)\xfa\r\xd5\xd86HS\x168\xc7\xa3S\x8c6boe\xa9\x90\x92^l\xee43\xcc\xc7\xdb\x1c\x8b\x08W\xf9K\xd7\xea\x9e/\x98\xaewCJ\xff\x82\xbf\xf3\xc5X\xeb\xc2\x8bq\xeb\xa7\xbd\xed\xb0P~h'
        b'\xb7Sk\x1aR\xe2\xab](B\xc9(^\x1e*\x12\xa7BR\x05p\xfeJ\xd4N\xf9M\xea\x16\xd0\xdc\xc4\xdf\x0c\xd1\xdc:\xdddK\x0e\xb8\x84\x9aj>\x08+\xec<\x15K\tq\xf4v\x08\x00Y\x16\xe8W\x1d\x8a'
        b'\xd1t\xaaG\xb5\x12\xa4R\xa0\x19\xfb\x05\x8d\\U\xcf\xc6\xc0z\x06u\x92\x8dT[S\xa4vv\xf0V5A\xd7|\xa4\x19\x13|\xafi\xa4\xe5\xf2>0\xdc\\o\xf9\x9f\x85Q*Y{\xf1\xac?wp\xba4\xc0'
        b'2\x0c\xa4\xb2\xcbO\x04A\xb1\t\xde:6\xfd\x99\x89\x84p\x81\xa9\xa4\xad\xc4\n\xbbE\xb3f\xa7\x11h\n\xc4\xa0\xfb\xa2\xdazB\x9c\xbby\x92zld\x99\x87\xf3\xa0\xf4(\x94\x17obY\x89b\xb6\xcc\x15`\xa9'
        b'ccbw\xad\x92[\x1b\x98\xf0eM8v1\xa2\xbd\xbb\xb2\nIx\xd1+\xf5\x05\x05,\x8bD\x07\x1d\x94\xeb\x96\xfc\x0f\xc8(\x06Rg\x85\x16\x9a\xb2\xab\xee\xb2u\x7f\x85\x8c\xd6\xfdJ\x86)\xdb\xe3\x10\xa3:!'
        b'\xd9.\x9b=\x8f\xe4\xc7\xf2\x91\xfa\xc3P\x18\x0e\x9bn\x17s:\xbb\xee(\x9a7\xb75\xbd\xe9\xd3\xefV#\x80n\xc13\xea\x84\xb9!\xfe%\x8a\xa5\x1d\xb7\x96\x90\x9ds\x0e{\xbf\xfa9>\x18\xf1`\x7f\x13\x00\xad\x92'
        b"\r\x02\x00\x82\x18\x1a`0\x87\xadGE%\xf9\xa4\x05\xd8\xd3\x0b\xae\x8d#\xdexl\xfd\x05o\x10rH\x0c\xed\xc2\x08+\x9d\xbe8\x9f\xa8}\xcfT/\xefQ:\x84\xb8\xe7\x8co\xd6\xcd'\x17ta\xe4\xb9\xeay\n"
        b'I\x08qHM<,\xaf\x83\xd4\xb7x\xc2/\xaai\xd5\xc5\xb3\x82\x13\xfc\x99i\xc0\xae\xde \xd2\xf35\x18B8r\xef\xbab\xa2HO\xac\xcc\xdc|\xf8\xf4\x00\x02\x08\xc3!w\xe6C\x03_\xa1\x96\xac\x8fa\xb5q'
        b'\xdb\xb2s\x129\x8e\xa8XZ\x16x\xb5\xc0A\xb4eAt8\x9crg\'\x84@\x9f\x8c\x7f\x8d;\xaex}\x19\xfc8\xb0F{AdO\xd5\xe2\xd6\\\xff=fh\x04"\xd2\xcb\x8f\xf6q\x85>\x01f_\xceJ'
        b'\xf7\xa9\x11\xa3+\x94\xc4\xd5z\xea\xd4\x84\x0f6x\x98\xb3\x08\x85\xf8=\xd9\xbb\x04\x05\xda\x14\xe7\x88A\x8e\x0fo\x80N\x8e;zb-\x0c\xdeE\xfdh\xda\xa3\x81\xd4\xf1a\xa9}\xc3X\xdf\x96\xcf<\xbb\xd1d\xc8\xdd'
        b'F5\xa4\xa9\xad\x85\xca\x19(K\x12\xc1-M\\\x8c\xfd\xf7tD\xa5\\\xe8\xc6K\x881\x8a\xb0\xe8\x8e\x02\x16z\nJ\xcaZ|\xe9\x12H\xd0\xa5\xb5\xd53\xc9\xe7\x1f{\xe3k\xd0\x1fw\xc29\xcc\x9f\xeb\x03\xe8\xc9'
        b'1b\x07\xc4\x88\\\xe9qY\x9fo99\xc2\x05\xcd\x8d\x04~\xb4\xf9\xef9\xdc\xbd\x1d\xd8\xc0,\xddus$\xd1O\xb5\xbfS\x86\x1b\xe8F\xd6\x90\xd6\xea\x03\xa6\x95p\xe85 \xf4\xb9E\xdf\xf15\x9f>\xf9\xe8\xab'
        b"\xb3\x1b\xcc\xa5\xbaJe\xea2\x8c\xf0\x863\xfaz'\xc4\xa2\xa0\x06m\x8a1mQ\xd2\x18G\x1c\x11{\x13\xfb|\xb6Q\xb7&E\xb3\xe9\xc0bJyV\xdb\xe6[\x97~\xfe@Z\xbe1g\xa5\xf4\x8f;\xd7G\x02"
        b'j\x12\xed\x99\x0f\x14*\x0b \x91\xb4\x92\xd7D\xf6LDw_\xf9PS>\x15R\xc0\xda5-\xcc6\x93!\xf3\xf0\xcb_\x1b]\xfb\xb8\xceC\xc5g\x00\x0e\x08\xf5(\x89u\xcax:\xc8\xd9D\x83\x89Kb\x1c\xa7'
        b'H\x1a\xa3\x8a\x1d\xea5a\xff\x16 \xb0\xd0\x02&\xa7\r\xc1\xf4\x07\xe9\xf0c/!:\xd3\xdfN\x94A\xbb\xf6\xdd\x14\x05r\n\x147\x9f%a\x845\xa6\xf3!\xca\xd3\x8aMjUf\x03)\xb0\xb0y~fV;'
        b"o\xef\xa7\xe53b\xe9\x8f\xf4p'{\xa0\xfe\xd2dD<f\xa5jb{y\xd4\xd6\xf00\xb4\x9e\x06\x8f\x11\x83\xdeq\x1f\xe4\xcd-.9\xe8\r\xc7\xd2\xd4\xdafK\x87R\xcfb\xc1\xa9]\x8f\xec\x99\x01\xe6\xe3\x8a"
        b'\x830<\x1b\xb1^L\x8a\xe4M\xb6;\x83\x11\xa7b(\xdf\xfay.\xdc1\x12\x11\xf7\\\xe5\x9f5\xdc\xbf|]\x93T\x0e\xb4ghS\xf7\xbe-H\xcf &\x03c\xaf>\x7f\x06\xe5\xb6pQ\x00\xfe\xd5\xbb&b'
        b"\xf1\xc3u\x80?\xc1CP\xf5\xfe\x9c\xf9\x9b\xbe\xa4wH}\x07&\x04\xa9.\x9e\xb3#\xfe\x0e@\xf6\xef\xd5\xa8m\xb4\x12\x842!\x1d\xa1\xb2\xce\x07\xcb.\xf7'\xc6\xf1\x11\x8cH\xdb%u.e\xefI\x04\x03\x1c\xd3"
        b'Pmm\xd93[\x82\xd6:"\x11^\xb9/\x9d\xf5.\x02b\x9e\x84\xb7\xf2?\x15\xf7G\xe9?\xa6\x0fc\xbb\xe6\xc0vI\x10\xc5V\xe6\x85\xfd$l\xbcG\x12\xed+\xefx\xfc\xa0\xc2Vt\xab\x16\xf4\\\x00\x88\xf6'
        b'\x02\xd5$\x04\xceU2\xcdJ\xcc\x8dY\xdd\xc1@\x0eS\xec\xd7Z\xab\xd8\xf9{gu\xc7\xb4Y\xc6\xbdJ\xeb\x07\xfe\xdf\xd1\xd3\xbd\xee;e\xdf\xc07\xd6%<(N,TP\xe30j\xd8\xbdR\\\xaeC\x1fp'
        b'?\x18\x90\xf0\xdc\xfd\xcf\xf8\xe4"\x97\x92+\xd9y|m)>Dg\xf2\x0b\xa4\xc5\x0f;b\xb0\x13\x97E\x0b \x987\xdb%\xa2\x9e\x81\x84\x1cO\x10\xdc\x80zZ\x11\xbc\x86 9\xd7[\xfa\xf9<\x7fO\x88jG'
        b"\xf3\xc9\xf0\x8b\x12\xa3\x80U\xdd3\xf68\xcd\xfc\xaf;\xc4\xd7w* \x0f\x05\xc7$\x89\x94\xe0\xe9\x97:2\xda\x84P\xd6\x93l\x11\x94\xfa\xf9p'\x1f\x9d\xedN\xc1\\m\x80\xe3\x98\xad\xeaa\xd8\xa2\xf3\x95\x04\x150"
        b"\xbd\xdf\xe7\x00\x9c\x0b)\xb8\xa7^ \xdd\x82\x10\xe3\xd5\xb2\xf7\x94#1\xdc\xa0\xe4\x7f?6\x19J \x9a\x0e\xd2'\xc2\xfe\x05~,Y\x93\x8b\xcb\x16\x89\xdcK,\xd1 \x92\x0bF\xe6\xf4c\xf1l\xd6\xf7\x17\xb0\xc2\xe0"
        b'\x97c\xe2p\xf2So97\xea\xee\x91U\xccXM\x8dkb\xbd\x04\x1a\xea\xdeF\x1fT\xf9*\x97\x9c\xcf)\x8d\xb8\xff@\x9a\x9f\xf4a\xc4\x0b\x8dX1\xbc(Q\xf2\xa7\x04\xff\xd0\x92\x1cK\x87\xcf\xaf\x89\xb5\xa1\xad'
        b'\xb5\x06f\x1d\xfc>\x05Dz\xa8\xbc\xe3\xa3\xeb\xcc\xb7\xba\xf7:%vOW\xf1\x917\x8e\x14\xc9\x13Q\x06\x94$\xce\xf6\x1a\xbf\xed\xe3\xfeR\x17\x1a\xe7\xc8\xb9\xd1\xd5\xb1\xc6LU4i\xc2\x1fV\xcd\xaaRX:\xa2'
        b'\x9b\xb4sN\xd6\xbd\x8f\xaa;<{\xf4\x884S\xc5\x90^?Vv\x90qn\x95\xadH\xc3\t\xe6\xd2\x1f\x08\xedm\xc7\xab\xd0\xc44`\xf8\xb4\xba\xc6\r1\xb4\xe6h \xa0}\xf2\x84\x1ax\x02s\xa2\xff\x9bC\x95'
        b'U\xd7\x0c\xbf\x90\xcb\xf4\xe4\x7fV7\xbf\x81\xeb\x0e\xa6kC\xf2\xec!\xb2?\r\x96\xb3\xba?\x08\xb5\xcf\xd6>\xf0\x1f\xfb\x0f\x90w/x\xb3\xe4\x15\x8bu\xaa%f|\xdaw\xd1\xf0\xbd\xa3sx\xd5\xe5\xdbkn\xcb'
        b'\x14\x15\xda?%\xb1\x94\x91\xa0\xf6\x93\x1d\xd0\xacq\xe8\xa1E\xca=E\x87aJPc\xe7M6\x86\xeeb\x7f\x03&8\xdc<\xbe#\xa0\x8fH\xb7\xb3\xdf\x81\xda\xb7^\xfb\xce\xae\\\xacOd\x7f13\xd9\xd5\xd7\xf5'
        b'B\xfb\xe4\xc5\xb0\x18U\x94~^{\xc4%\xf2\t\x0e\xd8\n\xce\xec\xb3e\x0e\xc7\xe1\x9e\xe2a~\xa5\xdc\xa4I\x8b\xe6\xe0B\x1a\x9e\x95\xe8#\x84i\x83\xfb\xe3\x10\xb8\xc4\xce\x1c\x85\x8d+%\xa0\xb3\x832\xab\x7fW\xe5'
        b"s\xa8/)\x8a\xc0n\x8b\x9f\x1a\xd3\xf0\xd3\xf2\xe7\xf9\x17\xc9\xa2\xfbY\xb3d\x9a\x10l\xe3\xf3\xf9E\x90\x0b=\xd1\xad\xf0\xf3b\x13\xe3Sqg\x12\x85U\x8a,\xa6T\x85\xfc\x1a'\xc2\x03XB\t\x05\\\x81_\xb9"
        b'\xa1\x15$\xca\x0bnr\xaf\xf6B\xe2\xac\\\xf0\xdb\xd8G\xfec\xf1Qw\xcfw\xa5\xfe\xb8\xd2E\xba`\x87\x0f\x16Ua,\x93%[\xe6\xf9N3\x1f\xa0\xfc\x1c\xa2=9\xc3\x8f\x92\xa2\x97\xc2\x11\x9d\xcc\xf5m}X'
        b'\xc6`>\xf82\xf0\x1c\x87\xc4\'\xebN\x15\xaf]\x86}\xe9c\x84\x96+\xae\xccf\xebE\x98\x98\x1d\xe4\x04\xb8\xa9\xd6\xb43\xc4\x88\x8d\xa2Jk\xb8\x05?\xc0\\\x81\xe9\xb8\xf3\x97\x8f\x85\xe6nel\xf9+9\x1c"'
        b'A+\xf0\x97\xc8X\x0e\x81\x9a\xcbFj{\x8e\tS\x1f,\x92fX\x91 \x95LGP\xb6\xd0\xf6G\x06\xf5\xa2Yxi5\xc7\x0c\x9d\xb8\x87\xe7\xd3\x85\x12\xd44>\xb0\xea\x96\xb0\x1f7\x1e\xa3\x1f\xeb;\x17@^'
        b'{1\xcb\x8b\x0f\xcbx\xc2\x97j\xe9\x8d\xb9\x9a~\xc7X\xc4[!\xb4\xc6\xa3\xba\x9c\xa8\xb5b\xe8\xfc\x00\xcd\xc1\xaa\xf3\xf1\xf2\xf5\x0c\x8b\\:\xfb,,\xc5\x8c\x95\xef\xb9\x8c\x9a\xbd\xb9%\xdd/\x1b(\xde\xadj\x94r'
        b"\xb7\xa1\x90\xfdh\xd6\xdbQX\xe2\x97\x98xH\x0bo)\x83\xdaj\xd5a\x19\x7f'\x8c\xbc\x8c\x9eW`\x17\xfc<\x82\x8f\x84^\xa9r6$\x06\x19e3\x1b\xaf[\x95X\xa17n\xc4X\x9c\xf6\x17u\xa8\x8e\xa1\x01"
        b'\x015\xabha?\xe6{\x122\xb2\x15\x03\xbe\xeb[2\xca\x90\xbdrQ(\x9b\x81\xed\xf1$n\x16\xd5\xdf\x7f\xf4\x9a\xf7\x89b\x10\x06v\xb4\xd1\x9cA\x8c\x03 \xaeJ\x01\xdc\xd6gn[\x83\xfa\x8f\xd9\xfeZgb'
        b'W2w\x0e\xcb\x03\xe4%\xeb[\x96\xe8\x1b\xe3\x85\x9d9\xb8\x96v\x1c\xe4 \xae\xec"Af\xa8d\xa5wI\xednG\xcc{\x14\x1b/h#_\xf4\x93\xfd\x15\xa02\xbd\xea\xebB\x1ad\x0f\x9d\n\xb4\x82\xfc+^'
        b'S\xa9\xf2\xd5RJ\x08%\xa8\x054\xd64q>\x97\xadr\xb1\xe6\xb7\xb1cb\x12H\xad\xbd=r\xb4\xf0\x91\x8d\x02\x15j\xfdC\x1c\xf0\x04)O\xe2@BZS\xed\xbf\xc0\xf6\xfa$\xf27\x81\x92\xab\xa3\xae\xcf0'
        b'\x05\xfd\x89\xf4\xfa\xfc-\xf3\xa2KJ\xacF\xa98&Wl8\xcf\xe2k#\x8a\t\xe4a\n\xfb\x9f\x89\x01\x91\nR|\xe2o\xda\xa7L\xd1>n\x16\xd7\x99\xce\x83\xa2%\xf9g0\xa8\x17\x8aF_\x81d\xcc\x05%'
        b'\xc5\xa4\x1f\x82`O\x10\xc02\x19"\xd4\x84)\x8b\xa0R\xb8<f\xb1I\x07\xc7\x94\xc7\xaa\x1b\xe0\xc2\xb8\xf2:6Jt$Z\xac\xc6s*\xbe=?\xdc\xe0\x13E\xb2\xc2\x86\x1d\xd4\x95`\xf5\x03\xf6aC\x9c)2'
        b'\xd6\xbbZU\xbf\x92\x18\tt\x95\xeb\xab\x1c\xc1\x92\xa4\xee\xa8\x94\xf7\x91\xc6\x95wk,\x01\xd0\x96\x07\xe6\x1b\xb9\xe4\xfb\xcfw\xd48>w\xf1\xc3\x9f\x82\x81\x0b\xf1\xbei;\t:\xbb\x9e\x8b\x92\xc2\x1a\xa4\xdfiu\x16'
        b'\xa7U\xdd\x84US\xb4\x8fI\xdbR\x98;\xc6*\x8e\x1e\xe2\x87C\xb3\x8eZ\xd1T\xcf\xba\xe0\xeb\x9b\x1b\xba\xb7b\xaa\xcb\xb0\xbc\x8d<m\x8e\x861\xcf\xc3@\xdfG\xf9D\xe9<\xcf{\xcd\x11[\xe2\xd8\xda6\xa4\x02'
        b'\x91/^1\xef\xe2\x07Ru\x82\xb1m\xc1 \x9eNi\x93\\\x0f\x9e\xdf\xdae\xdd\x9d\x92\xeb\xc2\n\xf5\\\xbe\xabX\x11\x0c\x0b\xc4V\x86\xect\x8f\xb7k\xcd[\x0edq\x8d\xe1r\xcdQ\xd4\xacl\xa5\xffR\x8a\x10'
        b'pv\x9c\xed\x895\x01v\xeb\x91t\xbas1c\xdc\x90\xf6A\xcd8\xc6\xa03_cJgH;\x16f\xb6S\xf8\xaf:\x92\x85\xfct\xaf\xf0\x04\x9e\x11\x15"\xdb\xd2\xbe\xb6\x83\x94A{\x1d\x1e/\x82\xf0\x18-\x00'
        b'\x06\xab\xeeU\xc4c*\xbfV\x9ds\xf6\xb0\x00\xe3N\xe8\xa1K\x1d\x95h\xb3\xccL\xc3{=\xa9\x08.\xa5\x96\xc6\xbc\xccxZ\x0b\xb8P\x1f*\xf95\xa0\x1b\xdd\xb1\xd6{n\xcc\x86o\xaa\x90\x86E\xbfC\x93\xf3\x8f'
        b"%i\x8b\x1ay`\xce\xcf\x01}\x84\xa3|3Oc\x17XR.\x1f\x91\x81(\xb8\x90\x91<\xa7R\xe0E\x1eL,\xd6L\x96 @\xc6\x9dd\xe8LOT\x9a\xb1\xea\xbf\xb5\t\xb61\xe5\xa0[\xdb]'\xdcZM"
        b'rz\xfdi\x07\xec=\x17\x95\xf1\xa0\xd2\xb0K\xb7=O\x88f\xcaR7\xfe\xa6\x838^\xcb@\xfb3\xe1\xa3\nbf\x1ch\x1cN\x17\xb9d\xfc\xf8\xdf\xe0\xd4+i\xc9\xa4\xd9\x9f==\x90\x8e\n!\xece\xf3#'
        b'5\xd9u\xcc\xf5\xce\x92x\x87\xd0q\xbb\xefEz\xf4\x9d\x13\xf4)\xfe\xc6\xba\xd7x\xdcR\x82\x93\x84\x959\xed\x04\x0e\xd3z\xc5\x8e\xd3\\\xf12I\x06&\x8d\xf8\xf1\xccw\xf6\xe6]\xb1\xb7\xe3"*\x9a\xa4U}\xd6'
        b'h5B\x92@\x12]\xa4\xe5\x15\x85\x16\xdb-\xe4\xffYe\xdf\xbad\x04Lt\x8b,\xbb"\xaa\x9276GiN\x97B\xd5\xa1wc`\xaa\xb3E\xac\xa7\xe9\x0b\xe9m\xb0W^\xfd:S\xb0.\xea\x97\xbd\x12\xb7'
        b'G\xceK6\x7f\xea\x1c\xda\xaas\xa0\xd1\xd7\x8a\t\x08\xc5Q\xd9\x8d\x90z\xf9IW\xdcp\xc8J\xfc\xb9"<\xc1r/bp\xdc\x05\x1aNH\xfd\x1e8.,\xde"\x87bq99\xc6\x98C\xd9\xfa;2Q*'
        b'\x14\xab\xfcCn\x06[P{R%\xb6V\x13\xd2\x1b\xea\xa4\x85*]\xeb-i\x94\x10\xc2\x84[\xb8\x8b\xb8\xa4$K\xf3\x9b\xec\xc3\xe4\x82\x0f\xdf\xe7i\xb7C%\xb8Am^;\xfb\xde\xa4\xc5\xa2\r\xae\xa9a\xb9\xc4'
        b'\xec5\x03{\xb5oU`\x1e\x98c@!\xec\xd8\xf8\xc6\xd2\xf9-\x0eheN%1\xcd\xc9\xeaR\x15\xbe\xa6r\xe8\x9aid\n\x9f\x8bjf\xf9FMb4&\x127\xcc\x8b\xd3\xc7\xfa\xe7\xb1K\xea\xdd\x15\xf6\xb9'
        b'&\xael\xb2\xc8\x0e\xe0\xc1p\x827\x8d\x16O\xb8\x14\xdb\xc2R\x80\x9c^\x14\x1cz\xce\xaa\x0c\x9a\xc6\xe3\x99C\x07\xb5\xef\xa0\t0F\x1aO\xe2\xfetG\xd7t\xf23\x07\xa8{\x96\x03e\xae\xbasFh\x9d\xc4\xfd'
        b'\xa3\x07\xcb\x92\xd1\xb3\x91C\x9e\xf0\x87y\xb3\x03\x84Q\x01\x0ciR\xe4\xbe\xf2~p\x08\x00\xcbH\xd6bZ\x9f\x84\x8f\xf4\xc1\xa8\x98U\x8d\xfb\xde(\xc6\xab\x18\x7f@\xb4bSL\x10\x98Ek\x1d\x8a\xc4\xd8_\xfc\xaa'
        b'0\xe5\x86\xa9\xdc\xa5\xab\xf3p>\n\xb5\xe7,\x1e)\x92\xbf\xc9RC \xa5Z\x93\x83\x16\x87\x14\x95{c\xe8\xf4L\xf8\xe9^LmV\x00\xe0\x1b\x97\xfd}\xf2\x8f%\xb2|\x03\x11,\xd2 \xe9\xa6\xd9\x9b\xf2W\xed'
        b'\x92\xb1|+\xa5\xc5\x9ae\x93\x0f\xc8\xac\xec\xe9)\x83\\\xfa\x1a`\x14\xe1\xfd\xe1Ah\xaf\x02M\xdcx\xbeX\x88\xe6"\xd0\xdc}N\xff\x94=\x88\xf5K\x8a\xcc\xa4\xf58X(~}\x0f\xeb\x10\xc1y\xd0M\x9dD'
        b'\xb8;n"\x85h@\xd2\x8b\xf4`\x07\xf9s\x04\xc9\xde\xb7\x8d6\xb9\xca8\xb7 \xe1^\x9fG\xed/\xacs\xaaH\xdc5\x83\xf5XM\xc0\x16\x84\x16vI\x9f\xca\x13\x1f\x92C\xd2\xf8\x08\xdc\x16\xea\x03b\x86\x1bC'
        b'\x8c\xf8\xec\x9d\x17\x17\xb7\xd4\xe7\xee\x91O\xf9\xfa\xd9#^\x00Z\x91.AK\x0f\x1d\x99\xeb\x90\x17\x07W\xa9\x85\xe1\x01\xfd\x0b\x92\xf4~\x02\x9fG\xfaD\xa5MJ\\\xaf5\xa8r\xab\xf3\x92\xfc\xc9[\xd7\xe5\xc8\xd1T'
        b'Pc\xc7\xd3\xf1\xc8(\xff\x1c\xaf!Bw\x84\x1c\xe1\xae\x85F\x8e_H(\x95/[?\xe4\xe0\xe0\x1b\xc4N\xd9\x03@K\x92.#\x98\xc9\x12\t\xe6\xf7zR\x03\tF\xf0\x17\x1e\x90 \x13T\xd9\xc1\xd9\xda\x1b\x0c'
        b"o\xb6\xa7\xe5H\xcc\xb7\xa7\x0c@q\xbfn \xd8\x02\x8e\xbea(_O\xbd\xe6\xb0\xd6\x7f\xb3\xcf\x91\x00W\xc9a\x93\xd1c\xd1\x14\xa4\x8b\xe7\xbd\xf7'H\x10\xeeR\xa3(m\x84\x8d\xc9\x1e\xf9\xc0\xd6\xca\xd1%$\x8b"
        b'\xc8\x0e\x89\xbaz_\xabZ\x17\xe1\xe7\x85\xa2qMh\xe8\xa3\xae\xef\x06\xca\xc3\x88\x15\xd9++\xdf\xeb\xf8z\xb8]\xa1I\x96W*#J\x8a9\x893\xe9\xe6\x15\xf7Cv=\xf18\x16\xb8B\xe0oc\xa2\x82Ns'
        b'\xb1\xd03\xd3\xb0\xdfK`sk\xcf\xa6\x85\xd2qmH:PM\x10\xfd\xdc"*\xef6-n\xf8;\t\xaf\xfb;\x9b\xe9h\xa0\x88N\x1f\xfa\x98\x03\x12\xb6\xcau\x89\x1f\\=\xa3\xa8\x8f\xe6$5]\x0b$\x0b\xb0'
        b'X\xb8\xd4\x05\xc4\x84\x18\xd7\xd1s\x9d\xb8r\x92\x988\xbb\xc1\xf3?\xe8v-\xe5G,_\x1d\xe5\xdc{\xf7\x92\xe3\xb5\xb0\x04\x9b\xa9\x9f\xc8h\x9d\xf7sx\xda*\xa6Fpg\x18\xd4\xee#\xd8\xef\x1ea%\xa83\xc8'
        b"U\x81\x90\xe7do\xdcD\x1f~\x11|'-\xfc\xe9\xecl\x89\x86\xaa\xc5\x15\x083\xfd\x80\xfc\x80\x19`\xd2z\xeci;\x9c\x92,\x04\xf8]N\xf2V\xc3\x01\x11<F\x1f\x9d\xc1\x08\x0b\xc6Xx\xcc\xf6U5S3"
        b'\xfe\xf1G\x8cQ\xd7\x83\x92^\xb5\x93\x8d\xa3\xe4\xedd=Gn*\xbc\xb8\x96\xee?B}\x97n\xe4K<\xf7\xee\xb2"\xb0\xe9/\x18d]E5\xcb8$\xd9\xa8\xc3\xbc\xd5Q8\xa3\x9c\xbc)\x11\xf3\xcbl\xecI'
        b'\xf4\x0c\xc4\xd6\xf3{\xcf\x87#U\xeb\x8a\xe5\x02\t\x00?\xf6Tku\xeb4\xf2\x06,8on\xb9f\x91\x07\x9d\xa9\xc41\x81\x02\xdem\xbb\xaf\x04\x89\xb2*\x94>\x12\xf5\x91\x15\x08J\x1b\xc6\xf5\xf25s\x9a\xee\r'
        b'[\xcah\xdc\x1c\xc9\x13\x85\xaa\x11\x0c\xb1\x05\xfb\xe9Cm\x1a\xb9\xa1\xdc\xbb\x03\x97\xe4\xe0\xf4\xdfb\xb9u-\xdd\xb2\x10\xb0\x1e\xad\xe2u\x82\xd5Pb\x08\xd9\x8c\xc8P\xc4\x8c\x8e\xc2U\x91\x82X\xc7B\x84\xac5\xa8\xdd'
        b'\x90\x14px\xfdn\x01\x98\x89\xcf\x963\x0ezj\x9a0\x83\x19\xd2\xcc&>\x02\xe9\x18\x0bcDX\x14\xf5\x1a<\xf5\x10\xff\x97\xb8\xc5)Sq\x84I\xbc\x8d\xff\xbb\xa1\xf8\xf8V\xdc\xa4\x19C\xa5\x88\xf1\x88\xe5\x8f\xca'
        b'0\x84)\xa8\x19a\xd0\x904\x8f\xc5X"\xeb\x99c\x92\x8c\x86\x8e\xa2\x93~\x1eBN4\xa8\x89\xce\xe1\xc9G\x97\xcdY\xa6\x92\xfa\xd0!0\x02\x02{\xa9\x89$\xd2h/\xea\x1d\x91\xf0\x10\xb9\'\xa3GfA\xac#'
        b'\xed\xfb!o\x90\xca\xbeW\x14`\x0c\x9e1\xc8Y\t\xd6\x8c\x8b~d1%\xf7\xef\xec\xdd\xf2c\xf9G\xf7d\xe9\x80=\x9f\x1f\x9f\xf0\xc47f\xc7}\x93H\xb7\x81\x03QU\xe4P\xd8N;4\xde\x1e\x95\xba\x15$'
        b'\x99\xba`\x1bi\xc6\xdc\x82\x1a\x18H2~\xe5\xd8<(\x9f\x1d\xa3\xf1\xaf\x8b\x02\xcc\xceJ\x0b\x83\x99\xb4^nM\xae_\xc5\xea|\x98f\xa8\x85\xd8H\xb7\x1e\x15\xf8Y\xe3N\x88\xdc+\x9f\xdf\x91\x82\t\xc1\xa4\xac\xda'
        b"\x97\xa4F\x12\x15\x07\xe5\xd2\xab\xffQ[&\xd0i\xd0\xd8\xc2\xb8\xce\x0b\x8d\x13\xe6\x17\x15\xe2L\xea_\xc4\x11\xd7\xbe#\x11\xb4\xd1x\x83\xf6\xe3\xd0\xb7{\x06\xd3\xf1'c\x86\x0b\xfe*}\xa8\x10\x80G\xfdV*<\x0e"
        b'I?[\xc4\x12\xcf\x17\xa5K\xa8[/\xa6zNz\xef\xbe 4\xad\xca\xf6b"\x10\xed\xed\x93\xce@\xb4\x0e\x81\xf5-s$\t,\x8b\xaaWt\x0f\xde{e\xd4u\x0f\x0cd\x81\xbb\x95\xdc\xc9rU8\xb9\x152'
        b'\xc7M\xda~\xffa\x91J\xceW\xf2\x10\xc1\xafTK\xa8HF\xcem.\x9b\x16\xd49\x19:=u\xe4\x10o\xbb\xccj\x02\xcb\x11L\x84?%\xe3\xea\xc4\x194c\xd9\x95\xf5\xc1\xa3\\\xce\xabb\xaa\xe1Y\x9b;\xb7'
        b'(%7=\x8f\x9f\x9b\xc1^\xb7[\x08\xb8j\x94\x834\xa5j\xf6\xcb\x1c\xd6\xfdm\xa1\r-p@KZ\x9a.B\x02\xc2\x99\xf4\xa8\x02\x0chW,\xffG\xe62<\\;B\xce\xc3\x06\xa5BfQ\xafz6n'
        b'\x1c\xa6\xce&\xbeC\x1d\x9e\x8ci8\x8fW52\xf8\xca\x12\x03_\xd9I\xd9\x1f\x19\x9fO\xcb2\x1a}\x9ar\xeb\x82\x99\x000\xc0ku\x13\x1auP\xab\x85\xa7K\x9f5\xf2\x16\x81\x87\x0b\xb5d\xc4iB^\x9a\xb6'
        b'\xb7\xc0\xc9\x03:\xe3\xb5\xcc\\1{\x022S\xe5\xc6\xfa\x16\x90\\\xd39\x14\xa9\xac\xa7\x07\xe7\x859\x1d\x95g\x84\x81\x93\xa3W\x9b\xf7\xfeD\x10\x93cH\x10\xd9WP\xf9D\x12\xb8\xeeU\x84,\xfd\x0f\x9aW\xb9R'
        b'"\xa8\xa3\xa0\x02\x85CG\xa5f%\x8b*\xbd&"\xd6\xb2\xc4\xa0\x99\xc4\x89O67V\x058\x16\xda\x83e\x0e\xe9A\xe8\x1f6Ki~\xd0\x93Y\xf7yb\x99\xd6bZ\x7ff!e\xb2\xf3\x9d\xaa5\xab\xee\x10'
        b'l\xcd\xe8\x95"T\xf0\'\xa3\xe0\xfd\xeb\x9e\xe2\xf8<\x8c\x9b\xff\xb9\xff\xbf\x0bh\t\x15$N\x10\xdf\x97W;G\r\xb9\xaf\xa2\xdf\xeba\xf7\xf8WR\x83\x1ea.\xb7\x7f\xc9\xb2{l:\xb5I\xdehg\x8b\xe8\x9a'
        b'\x06[\x18\x1e\xfb\xae\xf9\xbe<\x00h\x17\xb5\xd8,f\x9e\xa9l\xb9\x9f\x82\xb1Kd)\xb7\x18\xe7P_\x00\xd6\xe8\x1d-\xf3\x9fA\xab\xd1\xb4\x0cf\xb8\xbfvg\xe5&\x9eTH\xcb\x83;\xc4k\x86:\xaf\xb3:,'
        b'/\x9dp\xea<t\x94\xdd\xf7\xd3K\xdf\x07\x0b\xaf\xef\xddi2\xd6\xabV\x04\xf0\x9fxL\xae\x03l\xe7a4C\x11t@\xe4\x9dX\x83\xac@\xec\x8bn]\xe7\xe2\xb2o\x8a\xf5`\xd7=E\xab\x94r\xca\xff\x88\xf6'
        b"\xc4\x1b\xda\x97\x18\xbe\xd1<\xa1\xd4\xf1\x97h/\x8c\xa7\xbcS\xaf\xfa\xfa\x80\xe4\xca\xc4s\x80\xb3#\x92\xb0\x0e\x82\xa1'\xaa\x8aSx%-\xd8P\xa2\xd8\x81\x1e\xa3\x8a\xfd\xd1t\xc6l\xc3K\x8d\x0cN\xe6\x8c5\xc0\x95"
        b"\x06D\xa4\xea|1F\xddK\xd3$G<2\x04\x00\xa3\xbe;{\xa8}\x86'&\x8bBh\x85\xff\xc1Q=w\xbf\xe3\xbeW\x10\xfc\x9b\xd7\xb1\x11\\%\xbc\xf8\xd5\xc3f\xff^`z\x0e\xb0\xa2\x14,9\xf2\xbc\xb5"
        b"\xbf\x12\xb7\xb1=RB1}\x05bs\xfbi\xe4\xe4\xd2\xbf4\x12j\xc3NX\x05;\xd7\xe1\x81F\xe5\xe8`x\t\xf3\x93\xbf\xd1=\xc1\x85\x167jz@\xf89\xd3B'#\x83\x05\x12\x04\x8e\x84\x93\xcd\xb6\xc9\xfd"
        b'\xb9xi\xc0[\x07\x8e\x07\x8b\x8d\xc5\xc4\x81\x10\xce:.U\xc5|\xf9\xe5\xa0s)\xd2\x81\xc6\xd2\xb2\x14\xfcl\xc7@\x1a\x14fcM\x19\x80\x9b\xe6<\xb4\x87O\xd1\xb1T\x11\x82c\xadW\xf7\x03\x82\x9e-\x17}v'
        b'\x1cK\x01\xebQ\x11\xcc\x0e\x18\xba\x06\x0b\xeaY\xd7\xc6#\xed\xf5\x1b\x7f\x9c\xc5\xb9\xfc\xac}e1\xf0J\x1eO\x98=\xd2\x04\x0e\xae\xbaT\xc7\x18\x87\xa0\x10\xe1\xae\xe8\x11A\xf4\x9a\xbd\r\xbe\xa3H\xa9|\x91h\xaf\xcb'
        b"\xc7\x0e\x10\x08p\x99>\xacX>\xf38\x10\xe4Q\xc5\x82k\xb0\x17[\x99\x15\\J\xd6\x81\x1d\x01$\x93\xe0\xbb\x9d\x14\x0e\xb0\xbf\x978o-\x1f\xce\xaf\xcaFb1.\xc0\x11\x9c\x1d\xbeO\xa7\x15\xe3\xad\x9eT'2"
        b'\xe6cW|hR\x8c8\x8c\x1b\xf9R\xc6\x16\xc5|\x93\xa9\x85\x9fj\xdb\xf9\xf82\x9eaC%]@=K\x88\xee\x83"t\'\x8a\x06\xd0\x92\xad\x10\xd9y\xab\xb4\xdb\xddr\xcb\xa1\xe1\xcc\x15\xfa\x91\xf6FuI\x12'
        b'\xf6\xceq\x9d\x10-\x82Nhog\xff+\xad\n\xd7\xae\x1e\xc3\xcd\xd7i\x93\x1bC\xc6C\t\x92&\xb5\xc9\xcb=\xb5y)\xee\xbf=\x95w\xce\xb5mgm\xd6T\x86\xa7\xa7\x12\xe6\xe5o\x81\x96]\x99\xcc\x89\x1b\x12'
        b'\xfe\t\xb9\x06\x96\xbdB\x17\x97\xf8A\xb621\xd7bh7R,L\x8a\x07\x0b\xd4\xd3\xe7\xd6\xb6\xb7\x18/)\xab\x9a\x07\x963m\x1b\x17z|_\xb4\xe7cL>\xc2\x82\x16\x11\xa1S\xe6x\x1e\x14\xba\xbe\xd9v\x86'
        b'\xb7\x1by\t\xc1\xc6R^\xd9&2\r7"7\x82Q\xd3\x00&\xf9\xc1\x10\x8a\x1e\x81\x92\xd4[_\xd3H\xbbRe\xb3\x05\xdb\x91\xe1h\xfa\x07\xa8\xa4\x92@\xb2\x805\x8bPT"\xee\xef\xf3\x95\xe4\xe4z\xd4\xd2\xfc'
        b"\xba\xb3\x87\x86.%\x1c7\xdf\x86'\xd9\xb4\xf5\rb\xab\xa6\x1c\r{\x03\xa1@D\x1e\xc9\na\x138\xb3\x06V\xdf\xcd\x93\x08M\xf2N1zR\xbd\xf1+\xac]tSD\xbaM\xef\xd5<\xb8\xdd\xad\xe9\x0b\x92\x81"
        b'\x10\x15\xc8Y\x86g\xde\xe2\xe7\x91t\xf3\xfc\xfe3\x9cD\xc5\xf9\xce\x0c\xae\xe8\x81c\x03\xa4\xf6hh\xf7;DP\x97?\x01\xd0}Z\xfc\x83E\xd1\xf9G\xc0\xc4\xbc8\x02s\x8e\x08Z\xfb]\xa0\xda\xce.Yv@'
        b'.\x1b\xf3k+\xe7\xab\xf74\xe4k\xca\xc8\xc8\xf7\xdb\x1bz\xc4\xd6"\x7f\xb5\x8fyA\x07\xe6T\xd49\xbd\x8cT\xb4\xa5;\xa5\x81k6\xd9\x10\xcf\x88\x19\x86\x02\xd5\xe7\x9f\xf4\x80\xbf\x84\xcb\xdd\x04\xdf\x99#C\xca\xd7'
        b"i*<vq\xac>Q\xee87\xb4\xd4\xd1\x01\xb4w\xa9\xdb$\x02R\x19k'\xedf\xc5\xbc\xb4V\xf6GEV\xc5\x1fYv\x9d8\x16]liV\xbf\x88Q\xf1\xa1\xb8\xc6\x8b\xc4\xf2j[ \xb3JNZ\x1c"
        b"\xa98\xee\x89\xea\x9c\x1e}\xb1c\xf2\xb6Yu\xe2\xa0\xed\xf0-\xaa\xe9\xd1|O*\xed\xfb\xc6Z\xe1J\xc1\x19A\xf2\x94\xa0^3n\xeeH6'7A:\xec@T0\xfe;wV8\xef\xc8\x10\xf0\x02\x99\xa5'"
        b'8\x83[\x9a\x17o\xb7V\xd0\xc8wsS\xf8\x94\xf9\xe6~l\x9a=&\x9d\xd8\xe7zx\x97\t\xd2\x19\xf2e\xce\xfa\xba\x18SmB\xe6\x14\xd0\xdc\xca+\xc1\xe4\xc3\xbbh\xf6\xae\x80\x80\x07\x98\xff\xb8\x15mY\xec\t'
        b'~\x1f\x83\x88\x01V\x9d\xf8\x82\x88\xff(\x82\xadB\x06!\xae\xb5^T\x9a9\xf5\x9f\\}\xec\xc6\xda\xb3\xbc^W`\x0c\xe6y\xddB\xc8\x15\x04\xbf\xbfL\xa0t\xcc\xb2\xb9\x00\x14<\x0e\n\x15\x0f\xad\x8e@6\xdf`'
        b'\x0f\x1b\xc7: -e\x06\x98w\xe3\x80;\x15\xa1\xd3\x0b\x85v\x04\x92\x17Qe\xabTB]\xdc\x85\x00-\xc1\x9c\x08\xe5\xfa\x15h\xbe\xb7r\xf2?\x8awe\x819\xc5\x98\xa7\xbc\x12"\xe4y\xc8\x82JH\xfa\xb4)'
        b'\xca\x15\xe8\xbfAE\xf4\xb0&_h\x8b\r\xb7P\x06^=p1e\x81\xd2w\xb1q\xbc\x12\xe4\xbd\xb4\x01\xba\x82CV\x0fG \xf5\xa3U\xef_[\xca\x8d0@-9[Q\x0f\xd6\x00\xc5\xfc"j<{v\xa6'
        b'N\x84H\xe0\x83aS\xf7\x86\xfem\x83\x85\x84\x81s/\xe9\xe4\x18\x154H5-\xde\x8d\x15\x18\x14\xee!bh\x8b\xc1\xdc4\x1f\xc3[\xe3P\xb2\xf3dsx\xab\xf5^7r\x8e\x0b\xa2\n\xca$Bs[ \xe8'
        b"\xac\x0e\xe4@\x99\xd2\xb7\xfa\xa4'\x8f}\x87\x07\x812'\xc2Y\x90\xd1;Z\x84U\xad{\xb8\xee\x9e\xe3\x08_\xf3l\x84\xb7m\xeb*\xac\xd2O\xad\xa9\x9dqE\xbe\x84\x07\xd4\xa7\xdb\xb9/\x03\xd5\x7f}\xdf\x1b\x96P"
        b'|\xc4+\xb8;\xebp\xb2M\xf1 h\x0b\xe4*V\xd5[@X\xe2wr\xb4\x8a$\x01\xb6\xd4E\x8d\xc6\x9f\xa9\x9d46\xca\xa1K\xb1\x15\xec&\xe3iMw\xc43;\xa5\xc1\xd12\xbe-\x8bT9jt\xfa\xc2'
        b'5\xdcR\xb2KP\x15G\x8f\xa0u\xe0r\x02\xf1\x87SU@o"\x0fM\xfb8\xe3\x15\xf4\x8e_6\xc8&g\xa3\xfc\x07\xc4U;V9\x9a\xfd\xc0/\xc5\xc2uL\xe9\xc5\xc5p\x0e\x95*X\x8f3\xaf\xd3}\x9c'
        b'\xe0\x83|\x9f\xd7<\tS\xd5R\'T\n\x81"G9\xbaT]\x96F\xc3\xda\xc4\xb8\x0f\x1b\x9c\x93\xf6\x86 \xe8B)s[\xab\x89c;p\xf9b\xf6M\xa2\xcb\x82&\t\xd9\xb9\x1a\x05<\xc9\xde\xd2\x86\xbd\xd8\x8b'
        b"\xcfrG6\x9b\xa2\xe5\x8d\xc7\xea\x11\xc7\xd8\x19B\xa4\xfe\x95\x16\xbaf\x8f\x9bqG\x06\x85\x1a\xe0'd:\n\xc5-i\xc3)\x85\xb4\x9e\xcb\xa5\xf7\xa3\xbfms\xa8G\x10l/v\xfa\x89\xf3\x14\x16-\x0by\xa9\x89"
        b'f\xd0\xff\xbd\xb1=2KcQ-\x1f\x9d(\xafq-\xb1\xf9#\x91\xbe\xebY\x8c\x9f\xcf>J{\x96[\x89\xc54\x14\x18\xa2\xd01\xef~\x07Zd\x8b\xa9y&0?\xcf\x13<\xcc\x9f5\x9f\x0fP\x95l\xba\xb7'
        b'\xd1K\xc1\xcf\xa9h@\x05J\xb5\x9d)i\xd1\xdb\x11\x9e\x7f\x04\r$n\xf5\xb7\xa32E\xa9\xf8\xc7\xf3\xdfd\x9e\x13\xe0\xc6\x1c\xa1\xc5|\xcc<\x06@Q\xa3p\xc2\xe6\xa2\x01\r\xc4,Z!T\xd1DW\xe0\x19>'
        b'/V\x8c\xc4dh\x03\xbb\xf7R\xa2\xae\x9dXM0\xe6\x8f\x8e\xba \x08\xc9=\xe2\x08\x1a\xbb\x03\x1c\xa2Q\x86\x85\x19\x81L\x9d\xbc\x9c\xf7\xe5\xf3\xd1\xb8\xc7\xf5\x05K\x18\x07\x02h\xf7\x0eh\xa6c<\x9d\x90\x0c\xcf\xa4'
        b'\x1a\x13\x8b8\xa9\x97\xab\xc1U7\xcf\xa4\x93g\xa4\x99\x1b\xa7\xc5.\xe6\xdaq\x04^s\xc0\xec.\xf6\xf5\x19[!c[\x99\x15m\xee\x16\xe8^\xb04\xa7s\x17O\xcb\xbc\x8cr\x9b*\xb6\x1e\xd0\xe9\x14\x8eB\x8d\x9d'
        b'\xfe\xbb\xfe\xb6\xd0\x9e\xb0\xb3\\7$\x9c96Bs\xdd\xc5\xd0\x1be?\t\x99\x05\xed\xbcU\xd8\x10\x90\x14+\xf6R\xf0\x90\xd8P\xda\x9e\x94\xcfq\xe81\xec\xf3\xcc\xde,8\x1c\x04\xb5=`\xb4`\x8b aD\xb5'
        b'sp[\xdf\xe7\xd3\x05H\x91i\x80\xe5\xaao\xc6\x13\x8e\xcf\x8bmG\t\xf1\xb6\xa7\x1d\xe4YU\xeda\xb1\xe5\xe03\x8d,@\xb5pF\xbdF3F\xe1\xf9\xf9K!\x14\xa7\xbe\x16\\\xda\x01\x947\xb6L\x18\x89\xa0'
        b'\xd1\xbc\x99\xd8\xf4H\x02\xddViM1\xb6#S\xbaf\x90\xc6\xa8\xe3\x14\x08\xfaP\x14\x80\xe1\x180#\x96\xa1\xe1\xc0\xb9S\xdf1_\x84\x9a\xebY\xc6\xac\xdc\x1a\x11\x8e\xa5\x15\xf4\xff\xf4HWfB\xde\xe9\xaeh\x9e'
        b'\x0c\xd5\x9b\xe4\x98\x06]\x19\x7f\xa4(\xc8k\xc8\xd6\x07Z\x1fe\x91\xaf \xef\xac!!Ob\xb9\xea\xc2\xdd\x1d\xb0ya3\xb8)RU\xfd\xb3\xac1\xfc1D\xd9Yz= \x1a\xf3\xd1\xd1\xe9\x05\xc4\xad\xf2aN'
        b'C#Qs9\xa9\xd4\xb6[A\x98\xdd\x0ck\xe2\x8bw\x91\xf2\xe6@m\x9a\xee\xb6\x08\x00>\t\xd6\xcal\xd2\xdf\xb0+0\xd9\x96\xfd\xcb\x14\x81\x93O5K0j\x1b\xc16K\x06\r]\x9c\xdd\xedv\x1c\xfbE\xaa'
        b'&\x9bY\x14w\x16\x82\xcf\xea\xac\x99n\xfb\xd6\x98\xeeO\x9e\xf0\xb1\xae\xf9\xf0\xf0e\xdc\x08\xf5\x18\xa1\xa2C\xfb\x05\xa9\x83&\xbeg\xea$\x12\x1a\xc5\xe55\xe5\xc2\xaa\xef\xbb\x87\xe3Q\xe7\x87\xeaY_W\x8a\xfe\xfe/'
        b'\xcd1\x84\xe1V\x89\x822\x1ew\x94z\xf9\xd4\xfa\xe1\xa5GDM\xca\xeaZ-\xf3^\'9\xf1\xb1Ni}\xabb\xa7\xcfS\xdb\x12\xd4T\x08\xf6N\xe4,\x95"2\xd8\x8d\xd5\x0cY\x01\x0b\\0!B\x193 '
        b'\xabS\xe0\xf0\xe3I\xc4\xb9\x1dFh\xba=\x15\xc7\xad\xe6\x18X\xd0|-\xc7 \xe5\x99\xd6B\x1e\xe0\x05\xd4\x97\xbb\x04\xc9\xb7\x13\r\x92_\xe5\x88\x06\x83\xc7:;M\xfb\xdf\xf0H\xc4%2&\xdb\xdd\xd1\xe2\xe2\xd4\xb3'
        b'@\xef\x8c\xc5`\x8e+\x02vl\xdc\xc5V\x03\xeb\xb2\x8fJ\x1c\xcf\x02\x84[\xd5\xe5\x9d\xcc_C\x8f\xd0)\x86\xb2R\xae$\x0eGK\x10\xe6\xb3\x13\xa8n\\\x01\\\x85`\xbd$\x87\xe1\x86@\xdfI\xec?}3J'
        b'7\x9c\xabj\x83\x1a\xc7\xc4|\xa9\xc8\xefR#\xa9\xd7\xf5\xf0\xa2\x06\x94\xcc{5\xd9\t\xb9h\x11Iu\x9fU\x13\xe2\xae?x\xa8*\xe9\xfa6m\x015\x08J\xbfC\xbc\xab8\x13>\xe8",\xf4\'{\x88AD'
        b'W\xa3{\xbb\xe7\xb9\xb6\x11,h\xa2O\xd4\xa2\x94\x9d\x01*\xbc\xf9\xc2s\xbeg}/\xf4\xa6%\x8d\x7f\xc2\xb5%\x13\x03AhX\xef\xb8\xd5\xc4A\x04\xb9\xc8m\xdb\xff\x063\x1d\x97\xe7\xb7r\x02\x86\x91\xb6{\xbb:'
        b'\x10\xc2\xdd\x96[\xc4\x1f{=\x11\x18b\x93o?6\xa8@\x8b3\x7f\xadO\xe6\x08E\xc5\xd4\x9f5\x96\x04\x19\x1b\x16\xc2$-\x99\xfcLNO4\xf7\xca1u\xf4\x82\x1d\x89P\xdb=\xcfV\x89\x1f\xa5\xcb\x0b\x9f\xc6'
        b"?\xf3\xa3\xbat\xb2b\xc6\x1d\x07\xe7;\x1f\xf8\xd2|(gO\x1f)\x86\x92\x8f\xc8\x14P\x9c^h\xe6\x92\xaa\xe9\x1f\x08\xc7\x06\x9a\xe6F\xf7\xd8\xac\xbf|\xa3}\xb8\x03\xf5\xbbj\xb0\xf0\xc8\x8b=\x00'\xfb\x1d\xf2\x11"
        b'\xf7\xaaX\xb3\xd9<\x94}\xd9\xcf\xaf\xb4\xbdj)qN\xdc\xaa\x10\x901\x96\xa8\xd8\xd4\x016\xa8\xce\xa2\x9en\x8bX9\x96\xa9\xc1\x14\x15\x9a\xda/\xebF\xb0b\x1c\x1fo\xb4W\xeb\x1c,\xb8\t\x80\xb2\x14\xef\x04f'
        b'\xc5\xac\x89\ny\rT\xa9\x11\xbe\x12\xfc\\\xf5\x99W}\x02\x0b&\xc2\xc0e[\xb1SKE\x16\xd2\xf0c\x02\xe7\x9eX\x98\x08 \xd8\xa2\xf0\xc6v\x86S\x85\xecw\xbdw\xddfU\xe4]\x98\xbe{\xc9\x05d\x89\xc7'
        b'?\xf8\xe1~!\xce$\xd1\xcd\x80@\xa4\\\x89\xbe\xd7\xd8\xc8\x90\xbd\x8fq\x14\x8cQp\xfe\xe5\x10\xfc(b\r\xf0\x9aX\x13cS7\x1c)\x1a?uXpi\x88Lj\xc34\xaf\x18+I\xef\xb3\x88\xb5o`K'
        b'#\x86!\xdah"\x04\xdf\x9c5\x04\xccM^\x9a=\x80#\xa0\xc4\x0e@:\xfb\x1e~\xaf\x1b \xfa;\xc6\xe5\x88\xac\x18\xe8i\x1a\xa14\x9bo@eeE\r\xf6\x86\xec7\xcc\x99\xc4\xfa\xd1 iF|\xb3\xb9\xe5'
        b'\xa8b\xe6o\\`sI\xeb\xfe\xb9\x01\xda\xdc[\xe4\x19:\x97\xeb\x87\x04\xcd\x94\xf7\x1b\xc1@\r\xec\xf2\x1c\xb2\x82\xd0\x85`\xe8\xa7\x82i\xb5\xbd\x13\xb3\xca *\x1cz\xeb\xde\xbc6N\xbd\xe9\xddu\x93\x18\x0f\x85\xe9'
        b'\x1a\xa3\xc4.O0VJ\xb4\x93j\x1b\xacFC\x1as\xee\t\xee\x1e2\xab5Z\xd7\xad\\\xa3\xc2XL\xf0\xa1L\xd1\xc1,\xc9\\zu@\x85\xff\xab\xf4\xa6D4\x11uu\xbcB\xb9w\xab\xe5g^Bd\xae'
        b'\xb0#\n\xbf\x0bK\x05\xf8\xfd\xffuZb\xae\x10\x91wM\xeeh\xd9\xdb\x01\x87p2\x9a\xa1\x81\xbf\xfb\xe5-\x0c\x07\xfb\xd3\xfc\xd3\xa4\x7f\x90\x9d\x11\x05\xf5\xe6\xeb\xc4\x18\xeb\xaf\xae\xaf61\x13\xf2=6,\xc6+J'
        b'k\xfc\x83A\xb1\xef\x00\x08\x1c\xa3\xdb[;\xe6\x98\xe0\xd3\x84\xd0\xba\x82J\xfbf\x8bS1s)\xe0\x01\xb8\x82\x18q\x92\x18\xb2r\xc9nHc\xfc\x0e\xc8\xfeY\xa5\x11\xf1Y\x9e\xed\x10\xf8\x80\x87\x8f\x1e:\xafu6'
        b'\x19\x97\xd7\xcf`t\xd2K0"\x18\x00\xd29"Q\xcc1\x94\xa1\xd7\xa3\xe3 \xeb\xfe\x95\x8aY\xca\xc1O\xd6V\xc5PKm1\xba\xbd~\xf7\xd7OB\x16\xd2\nN\xc0\xac\x97\xa7\xe5\xbb\xda\x87\x86\xf6]\xc8!\xf6'
        b"\x10\x8a\x84\xb1\xc7W\xa3Q-\xcf\x95\x05y\x06'm\x10\xd4\x8b\xc2\xb7Cc!\xbb\x7f\xa9T)^\\x\xfe\xb2\xd0\x07\x164[>\x1e\xcf\xac\xda\x00\x15\x86\xd5\x18M\xfa\xcckq\x04\x08\x06r\xfd\xbe\x9cd\xb9\xb7"
        b'\xd2<\xbaKs\xc2\n\x13\n\xb27gL\xe9\xe4}\x1c\xe6c\xff9N\xbf\xa8\xb5\x1e\x02@\xa6zd\x8b:\xf4s&\x9a\x03\x83"\x8e\x16J\x8b#\x8e\x83\xe3\x9f\xe5T\xe3~MEL,\x9c\xde\x18\x8bq\xf1#'
        b"\xe6\x1bo\xbe\xcf\xff\x8b\xac\xfc\x12j\x83a\xa8\xee\xadLP'\xd2!\xc5\x9f\x7f\xa8q^\xac\x14qlj\xe3b\x18\xf5\t\xfb\xdd\x01\x8a\xc3\x86\x02\xd1\xcb\xfe\xfa\xc2\x03\xe7\x1bQ\xdf\xd7\xd0\xb6RG2\x80\xc6\xcfs"
        b"#\xe1\xf8\xe7\xe2\r;T\x0b\x86\x1c~\xf7\xbd\xcf>Qu \x93%\xact\xf5\x8a\xebcMq\xc0\x8b\x83\xfd\x8f/\xdf'\x98\xefp8+/\xe1$\x0c\xb9\xbb\x0c\xb2\x9bmL\xda\xcda\xae\xda\xfb\xb9\xcd\xa5\x89."
        b'h\xbf\\\xc7\xc3\xb7\x99\'y\x06e\x97"\x86\x94VTo\x83\xfd\xbb^\xc8\x80c\xa93]\xd9%\xf0\x8fW\xffs\x12(\xb7\xbc.\xc5\x81\xfa\x88\xdd\x03\xfav\xc8\xb0\xb5\x9b\xf5\x17\xdd~Y\xfa\x84\x1c\xbd9\x9f9'
        b'\xea\xe7\x98*}\x89\x8d\x9b\xd6\xe0\x80\xa9vi\n\xc2\xdb\xc0\xa2\xfc!\xb7\x9f\xd6t\xf8\xd6#\x06y~\x04\xd2\xad\xc6\xb4\xba\x95\xa7\x1b\xa2\xb4\x04MC3\xda/\xc6\x83rhp\xafA\xae\xdarS\xe3\x99\xe0Z|'
        b'\xdf\xde\x0f$.\xb9!\x12\xbd\xa7\xd3\x08,\x00\xca\xa1\xd7\x92)1\x85\xfe\xa6\xd3\xd9\xc2\x92zz~\xa0\xa4\xa6\xae\xba<\x9f\xd6\x15\xfe\x99Z\xde\x15\xd92\x08d\x90\x9b8\xf0\x88/r7\x19wT\x11\xf7\xf5\xb5\xbc'
        b'<\xab\t]dIq\xb5\x8f\xe3\x9f\xf2Wmt\xf1)\x0b\x1f\xb5B\xba\x9a\xab\x03\xda T8\xb8\x84\x19-\xb8\xabEi\x10\xf0\xf5\xdd\x9ct\xa7\xf0\xc4\xef\x053\x1c\xaej\xad)\xf5\xc0\xd5]\xb4DI\x08ij'
        b'\x81s\xfb\x83\xa8\xc7A\xc0\x04|4\xdb\xdb\x96n\xdd0\xb5\x83\xcd\x19rzf\x7f\x1fs\xc1mQ`F,_\xf3\xcf\xeb\n\xe1\xe7\x99g\xe7u\xa7\x9f\xb9\r\xba\xa5e\xd7\x03\xaf\xf7\x87\xef\xf1\x8c\x10-\x9f\xd6\xe3'
        b'\xa4\xba $\x1b\xc3\xd5E\xfeRn\xb7e3\x178\x8b\x06\xdc{\r\x8b\xd1\x0e-\xaa\xa5\x9cH\xb2P\x8bi\xd4+\xad\xc6\xae}\xf2\xc6O\xb6\xcc\x9e\x7f\r\x9e\xac\x11\xea\xbfM"=\xd5\xd4\xc6\xcapGR\x15-'
        b'\xf1)\xf3\x10\xd3\x19\xb2.\xa3P\x99W".=\x11\x81\x97d\xb2\x1b\x8dIG\xa5\xe1\xa3R\xe9\x0b\xf8Ye\x88I\xb3\xf4\xed\xde\x1ad\xc0q\xd0\xa5\xd98T\xa1\x1e\xb9\x83\xeex\x9b\x8e\xe4\x17\xee\xa4I\x7f\x93\x93'
        b'I\xa7\xa6\x12P\xcd\x9d\x1e\xe6.\xa2\xdb?\xa7\x12\xcb{\x87o\x98NxG\xb0\xcc\x16\xab\xf1\xae\xe3A\xb1\xd8\x1d\x1bk\xd5\xfa\xe9\xf86\x8dM\x9c\xf7\xf6\xf4\x10|\xddV\xbc\xe4\x19\xa5\x9d\xe6\xc5\x80\xa8\xd3\xebn\x94'
        b"ndp\xd84'8.\x8d\xee\xa8\xab\xdb\xcb\xe4\xc3f\xcbP\x16Y<X\xe5\xb6V\\\xecz\x15\xc9T\xecL1\xae\xe6\xa7CGKz9\xe90\xcd\xa42\xf7\xee\xbe?\xc0\r\x1d\xe7\xa2\x8b\xe2\x8b\xfb\xd7`\xd8"
        b'\x7f\xe6\xb3\xd2M\x93\xe6\xd4\\\x8bz\xb5\x8b}\x14\x1c\x86\xaa\xa6\xcf\xc6\x03\xd1\x0c\x8a\x1e,\xb9\xeb\xd1g\xbb\xa2\xf0\xf7\x83K\xbe\xcc\x90\xcc\xf69g\x83\n\x1c\x85\xba\xf8\xfax\xf3\x02I\xbc\xec"\xb4\x9ck\x8b\x83\xf5'
        b'L\xb6\x80\xe4\xaf\x03\x9e\\TP<\x16\x18\x1fk\xb9\xf8\xc3\xf8\xe0\xf5\xa8I\x9bf\x1eI\xa8\xeau$\xa3\xd1,\x1f:\t[\x14\x81>B\xe1/\xef\x0c\x90i/\xca\xa3\xa0\xd7:\xc4\x8a\xa0\xf1k\xa8\xf1\xe8\xed\x9b'
        b'\xfbOY\x18\\W~\xa3\xf71b\xa5\x00\xf4\xc3\\N"%AK\xe8wa\x88~\x16M\xf23b\x1cAV\xee9\xdc\xad\x01q\xd2Vt\x90\xca\x8b\x90\x0e\x83\x15\xc1U\xcc\xa2}y\x9c\x96~\xc8\xd3\xd2N\xc7'
        b'M\xb6\xb2A\x9d?\xa8\xd8\xf5\xfb\x15J\xfe\x1a\x06Q!\xf7h8\x1e@\xc3\xe2\x96m\xb4\xc3\x99Q\x7f\xfa"fA<ty\xb2$\x88"\x842N\x8c\x97\xac\x83\xe4\xb1\x0b\xcaTv@\xfc\x7f+\xe4\x0cv\x08$'
        b'\x89\xd0\x81j\xf2\xc0s\xfd\xd2\xa1c\xaa\x11U$\xc1\x9av\xef\x83\x96\x84\x98S\xfc\xc2q\xbb\xe5\xc8\x0c\x93\xb5\xcb\xb5\x94y\xc5\xdb\xb40\xaa\xc4\xda\x82q\x1f\xa1)\x07\xd9\xcf?\x9b*\xc4b\x9e\xc2\xa0\xb4\x08V\xfd'
        b"\x83\xa4:\xe0)s\x10\x16\xaf\xe6\xd1\xe9\xb2\xa0\xce&\x16q+\xbf\xfe\xbf \xe09\x7fW\xc5\xd3\x9fl\x87-\xab\x86\n\x805\x00\x15\xb3@'t\xc59\xd7\x1d;\xe0`AK\x90\x9a\x11\xa0\xfdm!\x95\xd4n\x1d"
        b'\xafJ\x18\x02M#!\xec\xa6\xe0\xe4\t\x02E\x02\x12\x85\xd2\x86\xdc\x80\x8a[E\xc3r\xcf\xcbq\xd7;<\xa1\xec\xa2\x92\\%\xdd\xaf\x0bp^\xa6\xe5Ye\x13\xa5/Y\xa0\xef\xa4\xf7\xdc\xed\xf8}=\xa8\xb0\xec\xdc'
        b'Qs\xb0\x9b\xc0`\xf4#\x01r8\xe0Q\xc7E\xa4\xb2\xa33 qJ\xd5\xc1\xa5\x87\rm{\x19\xfb!\xcd\xac\x12\xe0YX]\xd1\x18\xb3=\xc5]\x1fd\x15\xba*\xa0\xee\xba0\x0c-_\x9dZ\x12\x02e\x88\x08'
        b":4\x95\xcf\x96]\xdf&3\x9b1\x86-%V\xa5\nG\x8esf\x0225\xe1B\xeaS\x12\xe0t\x80\x94\xea\xc1+\xf0\x92=\t\xf2\xc1\xd2\xfawu\x99\xd0&\xa9\x0f\x95[\xcfut\xa0\xec\xd4\xf0'\xdf\x7f\xb0"
        b'JH9\xbb[\xf4\x9e\xce$\x89\x9c|R\x97\xaa\xb4E^=\xa4\xa8c\x04\xf3=\xe5\xdf\x176= \x1d\xb2\x11\x91ila.\xe9\x1c\x0e\xe6\xa9-\xf2P\x18\xbf\x92\xd1\xac;R&\x85\x0f\xbf\xe4\xe9\x1f2\xfbG'
        b"\xb8\xb3'\xbc\x07#iq\x01\x02\xc4#\xf9.&\xc7`\x1f\xc6\xbc\xa6\xefH\xff\xcd\xd1\xe1\x04\x08\xd0\xb9Q\xbb\xe1\xf4\xaf\xbd;6\xd1}.\x94\x9e\x81\x8fS`\xf7@\xb4\x1b\xeb\xb61\xf2PvwgH\xe4RM"
        b'\x82,\xeb_\x9d\x82cQ\xa4\xbb\xef\xc1)W#}A\x86\xc0\xb0\x01\xcdH\x80\xd4+)n\x90\xfdY\xbf\x81\xf2?\r\x10\xfb`\x93\x06\xc9-u\xf4\xbd\xbd\x9f\xcc\x8d\xb7~\x13\xe0\xcb\xe1\xe4\xe89\t\x94fzK'
        b'u\xe4\xef&\xd3p6a5\x9bDA\x94pf\x86\xd7\xc39\x9c$\x14N\x92\x0f\xa7\xbb\x82jAr\xad\xd5W\x8e\xcc\xdf\x93\x1e#\xbdi\xeb\t\x98\xda\xb8\xf3/K\x8f\xfetxg\rn\xb6\x88\xa8;\xb9aG'
        b'\x80\x05\xf1pP\xec\xee|$\xb8\xf8C,\xeb\x04\xb9K\xd0(\x12\xf3\x7f+\xca\xfe\x10&\x03pyz[\xb2\x12\r\x95\x8f\xd1\xdd\x9av\xd5\x08\xd0&R\xa2\xd6\xf4^\xady\xae\xa3\xbf\xfd>\x8b\xce\x8d\xafX%Z'
        b'\xe1\x05\x16$[\x91D\xd6\x02\x9b\xeb\xef\xcb\xc7\x8a\x0b\xae\xcd\xb7\xba\x926\xc9\xf8\x1d<}\xdc\xcfN\x96\x16!E\x98|G@\x1e\x12\\\xd3t\xc1\x8fv\x01\xa1\xb9Z\x04D\xe2@\x8868[\xd7\x82\x05O_\xa6'
        b'\xd3\nX\xcfyQ9\x01w\x118\x8e\x1a\x1f9\xdb\x0f\x16c8\xe3N\x83B\xe4X\xe1IV\xba\xc2\x9c`\xbezQ\x08\xae\xfa\xb8\xd1\xfaIb\x8ek\xf7q\x9d$\x1dE\xd2\xe8\xf8\x12\x82\xbfi\x0f\x00)\x1c\xd8'
        b'`\xdb\x05\xe4VTGZ\x82K\x8fq\xbd\x10c\x15h\xa9p\xa6\x0f\xefyD\xc1\x99\x1fF!Sb\xaf\xbb\xb6:4\xbc\xcfm\x15\xfdE\xc9\xc2Zw#\xa9\x9dS7D:\x13\x9b\xa0\x18\x16\x0b3\x19\xdaXm'
        b'\xaev\xf6\xde\xed.\xfa\xc7\x1e\xd2\x1a\x875^2\xa3\x1d{\x87\xed\xbf\x8b\x94I\xc0\xe7\x07"\xc5\x03b\xc6\x97\xf5\xd4\xc6\xbe\x0eQ*\xd2\xb26\x0f\xd3\xb1W?2\xe0\x1av<\xdc\x88\xf4U\x1bP\xa1>\xd4\xd6$'
        b'\xa9\xdb@\x91\x19K7-\xfbT)\x0e\x95\xcf`\xe2\xbb.\xdc\x93dR\x9c\xd2\xab\xeda\xd7r\x01AK\xa42O\x86\x8a\xf7\x04LH[\xe9\x04((q\x06H\x11\x14yL\xb6a\x14\xe0};Q\xe9\xb3z\x9f'
        b'*\x9d\xf3\xf4\xcb\x93\x8d\x8dY\x95\xe0\xdaWY\x8d\xdd\xac\xb0\x19\xda?\xf7\xb2\x9f\x96\x19C\xf0\xfe\xc0C\xba:\xa3\x1a2\xbc!iX_\x1d\x84\xdd\x9d\xda\xc9*\xd9\x05\xc9\xa1\xad\x05~\xb19\x19\xf6v9\x8d\x13*'
        b'\xe2\xa6Zf\xbdQ\xaf\x14\xe9\xc5y\x90]\\O\x95\x87jKD\rO\x1c~\xec\x11ZQ\xed\x82\xef\x06\xd5\\\xd1\x9b6mm\x1e\xa0d\xec\xd9?\xc71Jj\xe0b\x86\x8di\xe7}\xdbQ\x02\xc0\xf6\x84\xc5U'
        b'u\xc8\xea\xd5\xc1\xe0g\xe4\x1d\xd1\n\x06x\x14^{\xa2r\xc5\xc9\\\x86\x92\t"\xf4\x8f\t\x04\xca\xbc\xb1a\xc5\xdb\xa7\xa2.\x96+\x8e\x84\x93q\x00\x85_\xa0}\xb9#\xc4\x10\x15"P$\xf5\xac\xa9+d\xc92'
        b'\x8c\xec\xa1\xb1\xc8\x17\xda\x13""#0\xc5\xcaR\x1f\xf6\xf2\x1e\xb2o\xc1\x10o\xdf\x02a\x1b\\\x00\xf5\xc5\xe4\xacH\xdf\xdf\xac\xa5u\x8a\x08,x.=J\xa7\x13\xa85\x14\x01\xe7fI\xf8Y$\x96,|\x9b6'
        b'%h[\xf3n\xff+\x84q\x19\x84\x90%0\xac\xd9\x9a\xfa\x92\x84km\x8ah\xe8A\x1c>@\xb1\xbba\xe7\x8b\x10\xe3+\x03\xec`SVA\x05\x1a\xef\xa0\x0eyV\xab\x1a\xe8\xb7\x90\n\x98\x92\x1f\x94K`?\xa5'
        b'\x93\x03\xc8\xab\xeb\x81\x82\x9cc\xdb\xd0\x92\x85\x8b\xe4\xcd]\xa8\x9dry\r!j\x90\x1c\x88\xfc\xe2A\x1fq\xa0\xa7\r\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntim'
        b'eError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08'
        b'<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
